@@ -94,9 +94,11 @@ static INT translate_match(TRANTABLE tt, CNSTRING in, CNSTRING * out);
 /*=============================================
  * create_trantable -- Create translation table
  *  lefts:  [IN]  patterns
- *  rights: [IN]  replacements
+ *  rights: [IN]  replacements (heap-alloc'd)
  *  n:      [IN]  num pairs
  *  name:   [IN]  user-chosen name
+ *  This function consumes the right side strings
+ *  That is, it takes over their memory
  *===========================================*/
 TRANTABLE
 create_trantable (STRING *lefts, STRING *rights, INT n, STRING name)
@@ -253,15 +255,16 @@ translate_match (TRANTABLE tt, CNSTRING in, CNSTRING * out)
 BOOLEAN
 init_map_from_rec (CNSTRING key, INT trnum, TRANTABLE * ptt)
 {
-	STRING rawrec;
+	STRING rawrec=0;
 	INT len;
 	BOOLEAN ok;
-	ZSTR zerr=zs_new();
+	ZSTR zerr=0;
 	CNSTRING mapname = transl_get_map_name(trnum);
 
 	*ptt = 0;
 	if (!(rawrec = retrieve_raw_record(key, &len)))
 		return TRUE;
+	zerr = zs_new();
 	ok = init_map_from_str(rawrec, mapname, ptt, zerr);
 	stdfree(rawrec);
 	if (!ok)
@@ -507,6 +510,8 @@ init_map_from_str (STRING str, CNSTRING mapname, TRANTABLE * ptt, ZSTR zerr)
 		*p = 0;
 		rights[n++] = strsave(scratch);
 	}
+	if (!name[0])
+		llstrncpy(name, mapname, sizeof(name), uu8);
 	*ptt = create_trantable(lefts, rights, n, name);
 end:
 	for (i = 0; i < n; i++)		/* don't free rights */
@@ -622,16 +627,28 @@ show_xnode (XNODE node)
 		llwprintf("\n");
 }
 /*===================================================
- * custom_translate -- Translate string via custom translation table
+ * custom_translatez -- Translate string via custom translation table
  *  zstr: [I/O] string to be translated (in-place)
  *  tt:   [IN]  custom translation table
+ *=================================================*/
+void
+custom_translatez (ZSTR zstr, TRANTABLE tt)
+{
+	ZSTR zout = custom_translate(zs_str(zstr), tt);
+	zs_setz(zstr, zout);
+	zs_free(&zout);
+}
+/*===================================================
+ * custom_translate -- Translate string via custom translation table
+ *  str:  [IN]  string to be translated
+ *  tt:   [IN]  custom translation table
  * returns translated string
  *=================================================*/
-void
-custom_translate (ZSTR zstr, TRANTABLE tt)
+ZSTR
+custom_translate (CNSTRING str, TRANTABLE tt)
 {
-	ZSTR zout = zs_newn((unsigned int)(zs_len(zstr)*1.3+2));
-	STRING p = zs_str(zstr);
+	ZSTR zout = zs_newn((unsigned int)(strlen(str)*1.3+2));
+	CNSTRING p = str;
 	while (*p) {
 		CNSTRING tmp;
 		INT len = translate_match(tt, p, &tmp);
@@ -642,8 +659,7 @@ custom_translate (ZSTR zstr, TRANTABLE tt)
 			zs_appc(zout, *p++);
 		}
 	}
-	zs_setz(zstr, zout);
-	zs_free(&zout);
+	return zout;
 }
 /*===================================================
  * custom_sort -- Compare two strings with custom sort
