@@ -30,7 +30,7 @@
  *===========================================================*/
 
 #include "sys_inc.h"
-#include <curses.h>
+#include "mycurses.h"
 #include "llstdlib.h"
 #include "table.h"
 #include "translat.h"
@@ -42,7 +42,7 @@ extern STRING qSaredit,qSdataerr,qSsepch,qSronly;
 
 static STRING trans_edin(STRING input, INT len);
 static STRING trans_ined(STRING input, INT len);
-static BOOLEAN edit_valtab_impl(TABLE *ptab, INT sep, STRING ermsg, STRING (*validator)(TABLE tab));
+static BOOLEAN edit_valtab_impl(TABLE *ptab, INT sep, STRING ermsg, STRING (*validator)(TABLE tab, void * param), void * param);
 
 /*
 TODO
@@ -62,17 +62,15 @@ TODO
  * single character (the sep arg) between each key & value.
  *============================================*/
 BOOLEAN
-edit_valtab_from_db (STRING key, TABLE *ptab, INT sep, STRING ermsg, STRING (*validator)(TABLE tab))
+edit_valtab_from_db (STRING key, TABLE *ptab, INT sep, STRING ermsg, STRING (*validator)(TABLE tab, void * param), void * param)
 {
-	endwin();
-
 	unlink(editfile);
 
 	if (retrieve_to_textfile(key, editfile, trans_ined) == RECORD_ERROR) {
 		msg_error(_(qSdataerr));
 		return FALSE;
 	}
-	if (!edit_valtab_impl(ptab, sep, ermsg, validator))
+	if (!edit_valtab_impl(ptab, sep, ermsg, validator, param))
 		return FALSE;
 
 	if (readonly) {
@@ -95,20 +93,19 @@ edit_valtab_from_db (STRING key, TABLE *ptab, INT sep, STRING ermsg, STRING (*va
  * single character (the sep arg) between each key & value.
  *============================================*/
 static BOOLEAN
-edit_valtab_impl (TABLE *ptab, INT sep, STRING ermsg, STRING (*validator)(TABLE tab))
+edit_valtab_impl (TABLE *ptab, INT sep, STRING ermsg, STRING (*validator)(TABLE tab, void * param), void * param)
 {
 	TABLE tmptab = NULL;
 	STRING msg;
 	static char fullerr[78]; /* TODO -- fix static usage */
 	STRING ptr;
 	XLAT ttmi = transl_get_predefined_xlat(MEDIN);
-	endwin();
 
 	do_edit();
 	while (TRUE) {
 		tmptab = create_table_str();
 		if (init_valtab_from_file(editfile, tmptab, ttmi, sep, &msg)) {
-			if (!validator || !(ptr = (*validator)(tmptab))) {
+			if (!validator || !(ptr = (*validator)(tmptab, param))) {
 				if (*ptab) destroy_table(*ptab);
 				*ptab = tmptab;
 				return TRUE;
