@@ -9,13 +9,15 @@ ZSTR custom_translate(CNSTRING str, TRANTABLE tt);
 void custom_translatez(ZSTR zstr, TRANTABLE tt);
 BOOLEAN init_map_from_file(CNSTRING file, CNSTRING mapname, TRANTABLE*, ZSTR zerr);
 
-/* init.c */
-void dbnotify_close(void);
 
 /* keytonod.c */
 void cel_remove_record(CACHEEL cel, RECORD rec);
 NODE is_cel_loaded(CACHEEL cel);
 
+/* llgettext.c */
+void init_win32_gettext_shim(void);
+void llgettext_init(CNSTRING domain, CNSTRING codeset);
+
 /* names.c */
 RECORD id_by_key(CNSTRING name, char ctype);
 
@@ -32,7 +34,6 @@ RECORD make_new_record_with_info(CNSTRING key, CACHEEL cel);
 void record_remove_cel(RECORD rec, CACHEEL cel);
 void record_set_cel(RECORD rec, CACHEEL cel);
 
-
 /* xreffile.c */
 BOOLEAN xrefs_get_counts_from_unopened_db(CNSTRING path, INT *nindis, INT *nfams
 	, INT *nsours, INT *nevens, INT *nothrs);
