@@ -1839,9 +1839,11 @@ INDISEQ
 str_to_indiseq (STRING name, char ctype)
 {
 	INDISEQ seq;
+	/* 'B' is a code meaning try persons first, but allow any type */
+	char cmatch = (ctype == 'B' ? 0 : ctype);
 	seq = find_named_seq(name);
-	if (!seq) seq = key_to_indiseq(name, ctype);
-	if (!seq) seq = refn_to_indiseq(name, ctype, NAMESORT);
+	if (!seq) seq = key_to_indiseq(name, cmatch);
+	if (!seq) seq = refn_to_indiseq(name, cmatch, NAMESORT);
 	if (!seq) seq = name_to_indiseq(name);
 	return seq;
 }
