@@ -50,11 +50,11 @@ ZST qScrdbse      = N_("Do you want to create a database there?");
 ZST qSbdlkar      = N_("Argument to lock (-l) must be y or n.");
 ZST qSnormls      = N_("Cannot remove last person from family.");
 	/* summary of options (compiled with Finnish as optional) */
-ZST qSusgFinnOpt  = N_("lines [-adkrwiflntcuFxoC] [database]   # Use -F for Finnish database");
+ZST qSusgFinnOpt  = N_("lines [-adkrwiflntcuFxoCzI] [database]   # Use -F for Finnish database");
 	/* summary of options (compiled with Finnish as mandatory) */
-ZST qSusgFinnAlw  = N_("lines [-adkrwiflntcuxoC] [database]   # Finnish database");
+ZST qSusgFinnAlw  = N_("lines [-adkrwiflntcuxoCzI] [database]   # Finnish database");
 	/* summary of options (normal compile -- no Finnish support) */
-ZST qSusgNorm     = N_("lines [-adkrwiflntcuxoC] [database]");
+ZST qSusgNorm     = N_("lines [-adkrwiflntcuxoCzI] [database]");
 
 ZST qSronlya      = N_("The database is read only; you may not add records.");
 ZST qSronlye      = N_("The database is read only; you may not change records.");
@@ -191,6 +191,8 @@ ZST qScffdel      = N_("Remove this family record?");
 ZST qScffdeld     = N_("(Family %s (%s, %s)");
 ZST qScfpmrg      = N_("Do you really want to merge these two persons?");
 ZST qScffmrg      = N_("Do you really want to merge these two families?");
+ZST qScffswp      = N_("Do you really want to swap spouse orders?");
+ZST qScfchswp     = N_("Do you really want to reorder children?");
 ZST qScfcrmv      = N_("Do you really want to remove this child from his/her family?");
 ZST qScfsrmv      = N_("Do you really want to remove this spouse from his/her family?");
 ZST qSspover      = N_("Too many spouses to display full list");
@@ -253,7 +255,7 @@ ZST qSgdxmod      = N_("The record was modified in the database.");
 ZST qSnofopn      = N_("Could not open file %s.");
 ZST qSfn2long     = N_("Filepath too long.");
 
-ZST qSmrkper      = N_("Please mark a person first.");
+ZST qSmrkrec      = N_("Please mark a record first.");
 
 ZST qSlstnam      = N_("The current list is now named %s.");
 ZST qSlstnon      = N_("The current list is not named.");
@@ -290,7 +292,6 @@ ZST qSundsrc      = N_("Source %s is referred to but not defined.");
 ZST qSundevn      = N_("Event %s is referred to but not defined.");
 ZST qSbadlev      = N_("Line %d: This line has a level number that is too large.");
 ZST qSnoname      = N_("Line %d: Person defined here has no name.");
-ZST qSnomems      = N_("Line %d: Family has no members.");
 #if 0
 STRING noxref = SS "Line %d: This record has no cross reference value.";
 #endif
