@@ -608,7 +608,7 @@ indi_to_name (NODE node, INT len)
 		node = find_tag(nchild(node), "NAME");
 	if (!node)
 		return _("NO NAME");
-	if (!getoptint("UppercaseSurnames", 1))
+	if (!getlloptint("UppercaseSurnames", 1))
 		surcaptype = NOSURCAP;
 	return manip_name(nval(node), surcaptype, REGORDER, len);
 }
@@ -723,7 +723,7 @@ indi_to_event (NODE node, STRING tag, STRING head
 	/* TODO: break out following code into a subroutine for disp_person_birth to call */
 	llstrcatn(&p, head, &mylen);
 	if (mylen<(INT)strlen(event)+1) {
-		omit = getoptstr("ShortOmitString", NULL);
+		omit = getlloptstr("ShortOmitString", NULL);
 		if (omit) {
 			mylen -= strlen(omit)+1; /* plus trailing 0 */
 			llstrcatn(&p, event, &mylen);
@@ -1021,7 +1021,7 @@ num_spouses_of_indi (NODE indi)
 	INT nsp;
 	if (!indi) return 0;
 	FORSPOUSES(indi, spouse, fam, nsp) ENDSPOUSES
-	return nsp;
+	return nsp;  /* don't include self*/
 }
 /*===================================================
  * find_node -- Find node with specific tag and value
@@ -1157,10 +1157,10 @@ void
 check_node_leaks (void)
 {
 	if (live_count) {
-		STRING report_leak_path = getoptstr("ReportLeakLog", NULL);
+		STRING report_leak_path = getlloptstr("ReportLeakLog", NULL);
 		FILE * fp=0;
 		if (report_leak_path)
-			fp = fopen(report_leak_path, "at");
+			fp = fopen(report_leak_path, LLAPPENDTEXT);
 		if (fp) {
 			LLDATE date;
 			get_current_lldate(&date);
