@@ -99,22 +99,22 @@ remove_indi_by_root (NODE indi)
 	}
 
 
-/* Remove indi from cache */
-	remove_indi_cache(key);
-
 /* Remove any name and refn entries */
 	remove_name_list(name, key);
 	remove_refn_list(refn, key);
 
+/* Reassemble & delete the in-memory record we're holding (indi) */
+	join_indi(indi, name, refn, sex, body, famc, fams);
+
+/* Remove indi from cache */
+	remove_indi_cache(key);
+
 /* Remove any entries in existing browse lists */
 	remove_from_browse_lists(key);
 
 /* Remove from on-disk database */
 	del_in_dbase(key);
 
-/* Reassemble & delete the in-memory record we're holding (indi) */
-	join_indi(indi, name, refn, sex, body, famc, fams);
-	free_nodes(indi);
 }
 /*==========================================
  * remove_empty_fam -- Delete family from database
@@ -335,6 +335,7 @@ remove_any_xrefs_node_list (STRING xref, NODE list)
 			nsibling(curr) = NULL;
 			free_nodes(curr);
 		}
+		prev = curr;
 		curr = next;
 	}
 	return rtn;
