@@ -33,6 +33,15 @@
 #include "table.h"
 #include "translat.h"
 #include "gedcom.h"
+#include "cache.h"
+
+/*********************************************
+ * local function prototypes
+ *********************************************/
+
+/* alphabetical */
+static void fix_cel(NODE root);
+static void fix_children(NODE root);
 
 /*======================================
  * split_indi -- Split person into parts
@@ -164,6 +173,12 @@ join_indi (NODE indi,
 		else
 			nchild(indi) = fams;
 	}
+	/* fix parenthood of all children of indi */
+	fix_children(indi);
+	/* fix cache pointers of entire node tree */
+	fix_cel(indi);
+	/* validate entire node tree (if nodechecking on) */
+	nodechk(indi, "join_indi");
 }
 /*=======================================
  * split_fam -- Split a family into parts
@@ -279,6 +294,12 @@ join_fam (NODE fam, NODE refn, NODE husb, NODE wife, NODE chil, NODE rest)
 		else
 			nchild(fam) = chil;
 	}
+	/* fix parenthood of all children of fam */
+	fix_children(fam);
+	/* fix cache pointers of entire node tree */
+	fix_cel(fam);
+	/* validate entire node tree (if nodechecking on) */
+	nodechk(fam, "join_fam");
 }
 /*=======================================
  * split_othr -- Split a misc node tree into parts
@@ -396,3 +417,22 @@ normalize_fam (NODE fam)
 	ASSERT(eqstr(ntag(fam), "FAM"));
 	join_fam(fam, fref, husb, wife, chil, rest);
 }
+/*=======================================
+ * fix_children -- Set parent pointers of all immediate children
+ *=====================================*/
+static void
+fix_children (NODE root)
+{
+	NODE node=0;
+	for (node = nchild(root); node; node = nsibling(node)) {
+		nparent(node) = root;
+	}
+}
+/*=======================================
+ * fix_cel -- Set cel of all descendants to agree with root
+ *=====================================*/
+static void
+fix_cel (NODE root)
+{
+	set_all_nodetree_to_root_cel(root);
+}
