@@ -338,9 +338,9 @@ get_conversion_dyntt (CNSTRING src, CNSTRING dest)
 	zs_appc(zttname, '_');
 	zs_apps(zttname, dest);
 	dyntt = (DYNTT)valueof_obj(f_dyntts, zs_str(zttname));
-	if (getoptint("TTPATH.debug", 0)) {
+	if (getlloptint("TTPATH.debug", 0)) {
 		log_outf("ttpath.dbg",
-			_("ttpath trying to convert from <%s> to <%s>: %s"),
+			_("ttpath get_conversion_dyntt:from <%s> to <%s>: %s"),
 			src, dest,
 			dyntt ? _("succeeded") : _("failed")
 			);
@@ -360,6 +360,13 @@ get_subcoding_dyntt (CNSTRING codeset, CNSTRING subcoding)
 	zs_apps(zttname, "__");
 	zs_apps(zttname, subcoding);
 	dyntt = (DYNTT)valueof_obj(f_dyntts, zs_str(zttname));
+	if (getlloptint("TTPATH.debug", 0)) {
+		log_outf("ttpath.dbg",
+			_("ttpath get_subcoding_dyntt from <%s> to subcode <%s>: %s"),
+			codeset,subcoding,
+			dyntt ? _("succeeded") : _("failed")
+			);
+	}
 	zs_free(&zttname);
 	return dyntt;
 }
@@ -419,7 +426,7 @@ xl_load_all_dyntts (CNSTRING ttpath)
 {
 	STRING dirs,p;
 	free_dyntts();
-	if (getoptint("TTPATH.debug", 0)) {
+	if (getlloptint("TTPATH.debug", 0)) {
 		if (!ttpath ||  !ttpath[0])
 			log_outf("ttpath.dbg", _("No TTPATH config variable"));
 		else
@@ -449,7 +456,7 @@ load_dynttlist_from_dir (STRING dir)
 	struct dirent **programs;
 	INT n = scandir(dir, &programs, select_tts, alphasort);
 	INT i;
-	if (getoptint("TTPATH.debug", 0)) {
+	if (getlloptint("TTPATH.debug", 0)) {
 		log_outf("ttpath.dbg", _("ttpath checking dir <%s>"), dir);
 	}
 	for (i=0; i<n; ++i) {
@@ -463,7 +470,7 @@ load_dynttlist_from_dir (STRING dir)
 			UTF-8_ISO-8859-1 (type 1; code conversion)
 			UTF-8__HTML (type 2; subcoding)
 		*/
-		if (getoptint("TTPATH.debug", 0)) {
+		if (getlloptint("TTPATH.debug", 0)) {
 			log_outf("ttpath.dbg", _("ttpath file <%s> typed as %d"), ttfile, ntype);
 		}
 		if (ntype==1 || ntype==2) {
@@ -480,8 +487,12 @@ load_dynttlist_from_dir (STRING dir)
 		zs_free(&zsrc);
 		zs_free(&zdest);
 	}
-	if (n>0)
+	if (n>0) {
+		for (i=0; i<n; ++i) {
+			stdfree(programs[i]);
+		}
 		stdfree(programs);
+	}
 }
 /*===========================================================
  * check_tt_name -- Parse tt filename to see what codesets it does
