@@ -10,7 +10,7 @@
  lloptions.h - handling for (opaque) string & numeric options
 
   Options are fetched on-the-fly when requested
-   first from report properties (if getoptstr_rpt or getoptint_rpt)
+   first from report properties (if getlloptstr_rpt or getoptint_rpt)
    then from db properties
    then from global properties
    then from fallback properties
@@ -26,7 +26,7 @@ typedef struct tag_table *TABLE;
 /* initialization & termination */
 void free_optable(TABLE * ptab);
 void get_db_options(TABLE opts); /* free with FREEBOTH */
-BOOLEAN load_global_options(STRING configfile, STRING * pmsg);
+INT load_global_options(STRING configfile, STRING * pmsg);
 void register_notify(CALLBACK_FNC fncptr);
 void set_cmd_options(TABLE opts);
 void set_db_options(TABLE opts);
@@ -37,10 +37,10 @@ void unregister_notify(CALLBACK_FNC fncptr);
 
 /* routine use */
 /* TODO: fix const-correctness */
-STRING getoptstr(CNSTRING optname, STRING defval);
-INT getoptint(CNSTRING optname, INT defval);
-STRING getoptstr_dbonly(CNSTRING optname, STRING defval);
-STRING getoptstr_rpt(CNSTRING optname, STRING defval);
+STRING getlloptstr(CNSTRING optname, STRING defval);
+INT getlloptint(CNSTRING optname, INT defval);
+STRING getlloptstr_dbonly(CNSTRING optname, STRING defval);
+STRING getlloptstr_rpt(CNSTRING optname, STRING defval);
 
 
 
