@@ -61,21 +61,35 @@ should return.
 */
 void __fatal(STRING file, int line, CNSTRING details);
 void crashlog(STRING fmt, ...);
-void crash_setcrashlog(STRING crashlog);
-void crash_setdb(STRING dbname);
 
 
 /* dirs.c */
 BOOLEAN mkalldirs(STRING);
 
-
 /* environ.c */
 #define PROGRAM_LIFELINES 1
 #define PROGRAM_BTEDIT 2
-STRING environ_determine_config_file(void);
 STRING environ_determine_editor(INT program);
 STRING environ_determine_tempfile(void);
 
+/* errlog.c */
+void crash_setcrashlog(STRING crashlog);
+void crash_setdb(STRING dbname);
+void errlog_out(CNSTRING title, CNSTRING msg, CNSTRING file, int line);
+
+/* fileops.c macros */
+/* (add source location to calls) */
+#define CHECKED_fclose(qfp, qfn) do_checked_fclose(qfp, qfn, __FILE__, __LINE__)
+#define CHECKED_fflush(qfp, qfn) do_checked_fflush(qfp, qfn, __FILE__, __LINE__)
+#define CHECKED_fseek(qfp, qoff, qwh, qfn) do_checked_fseek(qfp, qoff, qwh, qfn, qfn, __FILE__, __LINE__)
+#define CHECKED_fwrite(qbuf, qsz, qct, qfp, qfn) do_checked_fwrite(qbuf, qsz, qct, qfp, qfn, __FILE__, __LINE__)
+
+/* fileops.c functions */
+int do_checked_fclose(FILE *fp, STRING filename, STRING srcfile, int srcline);
+int do_checked_fflush(FILE *fp, STRING filename, STRING srcfile, int srcline);
+int do_checked_fseek(FILE *fp, long offset, int whence, STRING filename, STRING srcfile, int srcline);
+size_t do_checked_fwrite(const void *buf, size_t size, size_t count, FILE *fp, STRING filename, STRING srcfile, int srcline);
+
 /* listener.c */
 	/* callback for language change */
 typedef void (*CALLBACK_FNC)(VPTR);
@@ -97,7 +111,7 @@ void set_usersort(usersortfnc fnc);
 /* memalloc.c */
 void *__allocate(int, STRING file, int line);
 void __deallocate(void*, STRING file, int line);
-void * __reallocate(void*, int size, STRING file, int line);
+void * __reallocate(void*, INT size, STRING file, int line);
 INT alloc_count(void);
 void report_alloc_live_count(STRING str);
 char * ngettext_null (const char *, const char *, unsigned long int);
@@ -115,7 +129,7 @@ BOOLEAN expand_special_fname_chars(STRING buffer, INT buflen, INT uu8);
 STRING filepath(CNSTRING name, CNSTRING mode, CNSTRING path, CNSTRING ext, INT utf8);
 FILE* fopenpath(STRING, STRING, STRING, STRING, INT utf8, STRING*);
 CNSTRING get_first_path_entry(CNSTRING path);
-BOOLEAN is_absolute_path(CNSTRING dir);
+BOOLEAN is_path(CNSTRING dir);
 BOOLEAN is_dir_sep(char c);
 BOOLEAN is_path_sep(char c);
 STRING lastpathname(CNSTRING);
@@ -125,7 +139,7 @@ BOOLEAN path_match(CNSTRING path1, CNSTRING path2);
 
 /* signals.c */
 void set_signals(void);
-void ll_abort(STRING);
+void ll_optional_abort(STRING);
 
 /* sprintpic.c */
 void sprintpic0(STRING buffer, INT len, INT utf8, CNSTRING pic);
