@@ -50,11 +50,16 @@
 #define LLWRITEBINARY "wb"
 #define LLAPPENDTEXT "at"
 
+#define LLFILERANDOM "R"
+#define LLFILETEMP "T"
+
 #define LLSTRPATHSEPARATOR ";"
 #define LLSTRDIRSEPARATOR "\\"
 #define LLCHRPATHSEPARATOR ';'
 #define LLCHRDIRSEPARATOR '\\'
+
 #else
+
 #define LLREADTEXT "r"
 #define LLREADBINARY "r"
 #define LLREADBINARYUPDATE "r+"
@@ -62,10 +67,14 @@
 #define LLWRITEBINARY "w"
 #define LLAPPENDTEXT "a"
 
+#define LLFILERANDOM ""
+#define LLFILETEMP ""
+
 #define LLSTRPATHSEPARATOR ":"
 #define LLSTRDIRSEPARATOR "/"
 #define LLCHRPATHSEPARATOR ':'
 #define LLCHRDIRSEPARATOR '/'
+
 #endif
 
 #ifndef INCLUDED_STDARG_H
@@ -77,24 +86,33 @@
 /* 1800 compiler warnings.  We still need to investigate *every* */
 /* instance where a STRING is dereferenced and the contents acted */
 /* upon directly to determine if there are sign problems */
+
+/* STRING TYPES */
 typedef char *STRING;
 typedef const char *CNSTRING;
 typedef unsigned char uchar;
 
+/* BOOLEAN TYPES */
 #ifndef BOOLEAN
-#	define BOOLEAN int
+#define BOOLEAN int
 #endif
 #ifndef TRUE
-#       define TRUE 1
+#define TRUE 1
 #endif
 #ifndef FALSE
-#       define FALSE 0
+#define FALSE 0
 #endif
-#define INT int 
-#define SHORT short
-#define FLOAT double
 
+/* INTEGER AND FLOATING POINT TYPES */
+#define INT	int32_t 
+#define SHORT	int16_t
+#define FLOAT	double
+
+/* VOID TYPE */
 typedef void *VPTR;
+#define VPTRSIZE sizeof(VPTR)
+
+/* GENERIC TYPE */
 typedef union {
         BOOLEAN b;
         INT     i;
@@ -105,8 +123,6 @@ typedef union {
 
 #define MAXLINELEN 512
 
-#define VPTRSIZE sizeof(VPTR)
-
 /*typedef VPTR (*FUNC)();*/
 
 #ifndef max
@@ -122,11 +138,17 @@ typedef union {
 #endif
 
 extern BOOLEAN alloclog;
+/* "stdalloc (" -- see macro below */
 #define stdalloc(l)   __allocate(l, __FILE__, __LINE__)
+/* "stdfree (" -- see macro below */
 #define stdfree(p)    __deallocate(p, __FILE__, __LINE__)
+/* "stdrealloc (" -- see macro below */
 #define stdrealloc(p, size) __reallocate(p, size, __FILE__, __LINE__)
+/* "FATAL (" -- see macro below */
 #define FATAL()       __fatal(__FILE__, __LINE__, NULL)
+/* "FATAL2 (" -- see macro below */
 #define FATAL2(qq)    __fatal(__FILE__, __LINE__, qq)
+/* "ASSERT (" -- see macro below */
 #define ASSERT(b)     if(!(b)) __fatal(__FILE__, __LINE__, NULL)
 /*
 eqstr does exact byte compare
