@@ -13,18 +13,18 @@
 
 /* WIN32 - COMMON INCLUDES */
 #include <io.h>
+#include <math.h>
 #ifndef _POSIX_
 #define MAXPATHLEN _MAX_PATH
 #endif
-/* WIN32 implementation - where should this go ? Perry 2001/04/06 */
-extern int w32system(const char *cp);
-
 
 /* WIN32 - BORLAND INCLUDES */
 #ifdef __BORLANDC__
 #include <dir.h>
 #include <dos.h>
-#endif
+#define int32 int32_t
+#define int16 int32_t
+#endif /* __BORLANDC__ */
 
 /* WIN32 - MSVC INCLUDES */
 #ifdef _MSC_VER
@@ -32,12 +32,22 @@ extern int w32system(const char *cp);
 #include <fcntl.h> /* _O_BINARY */
 #include "msvc.h" /* pragmas to suppress warnings */
 #define snprintf _snprintf
+#define int32_t __int32
+#define int16_t __int16
+#ifndef M_PI
+#define M_PI 3.1459265
 #endif
+#endif /* _MSC_VER */
 
-#else
+/* WIN32 - NATIVE FUNCTION IMPLEMENTATIONS */
+extern int w32system(const char *cp);
+
+#else /* not WIN32 */
 
 /* UNIX INCLUDES */
+#include <inttypes.h>
 #include <unistd.h>
+#include <math.h>
 #include <sys/param.h>
 
 #endif
