@@ -77,6 +77,7 @@ STRING nonlstx     = 0;
 STRING badargs     = 0;
 STRING badarg1     = 0;
 STRING badargx     = 0;
+STRING badtrig     = 0;
 
 /*********************************************
  * external/imported variables
@@ -356,6 +357,26 @@ children_node (PACTX pactx, PNODE fexpr, STRING cvar, STRING nvar, PNODE body)
 	set_parents(body, node);
 	return node;
 }
+/*========================================
+ * familyspouses_node -- Create parent loop node
+ *  pactx: [I/O] pointer to parseinfo structure (parse globals)
+ *  fexpr: [IN]  expr
+ *  cvar:  [IN]  child
+ *  nvar:  [IN]  counter
+ *  body:  [IN]  loop body statements
+ *======================================*/
+PNODE
+familyspouses_node (PACTX pactx, PNODE fexpr, STRING cvar, STRING nvar, PNODE body)
+{
+	PNODE node = create_pnode(pactx, IFAMILYSPOUSES);
+	iloopexp(node) = (VPTR) fexpr;
+	iiparent(node) = (VPTR) cvar;
+	inum(node) = (VPTR) nvar;
+	ibody(node) = (VPTR) body;
+	node->i_flags = PN_IPARENT_HPTR + PN_INUM_HPTR;
+	set_parents(body, node);
+	return node;
+}
 /*========================================
  * spouses_node -- Create spouse loop node
  *  pactx: [IN]  pointer to parseinfo structure (parse globals)
@@ -839,6 +860,7 @@ clear_error_strings (void)
 	strfree(&badargs);
 	strfree(&badarg1);
 	strfree(&badargx);
+	strfree(&badtrig);
 	strfree(&interp_locale);
 }
 /*=============================
@@ -903,6 +925,7 @@ interp_load_lang (void)
 	badargs     = strsave(_("%s: Bad arguments"));
 	badarg1     = strsave(_("%s: the arg had a major error."));
 	badargx     = strsave(_("%s: the arg #%s had a major error."));
+	badtrig     = strsave(_("%s: the arg #%s would cause an arithmetic exception."));
 }
 
 /*=============================
@@ -1128,6 +1151,9 @@ debug_show_one_pnode (PNODE node)     /* node to print */
 	case ICHILDREN:
 		llwprintf("*ChildrenLoop *");
 		break;
+	case IFAMILYSPOUSES:
+		llwprintf("*FamilySpousesLoop *");
+		break;
 	case IINDI:
 		llwprintf("*PersonLoop *");
 		break;
