@@ -254,7 +254,7 @@ evaluate_ufunc (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 		BOOLEAN eflg=TRUE;
 		PVALUE value = evaluate(arg, stab, &eflg);
 		if (eflg) {
-			if (getoptint("FullReportCallStack", 0) > 0)
+			if (getlloptint("FullReportCallStack", 0) > 0)
 				prog_error(node, "In user function %s()", iname(node));
 			return INTERROR;
 		}
@@ -282,7 +282,7 @@ evaluate_ufunc (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	case INTERROR:
 		break;
 	}
-	if (getoptint("FullReportCallStack", 0) > 0)
+	if (getlloptint("FullReportCallStack", 0) > 0)
 		prog_error(node, "In user function %s()", iname(node));
 	*eflg = TRUE;
 	delete_pvalue(val);
