@@ -258,7 +258,7 @@ interp_program_list (STRING proc, INT nargs, VPTR *args, LIST lifiles
 	} else {
 		PATHINFO pathinfo = 0;
 		STRING fname=0, fullpath=0;
-		STRING programsdir = getoptstr("LLPROGRAMS", ".");
+		STRING programsdir = getlloptstr("LLPROGRAMS", ".");
 		if (!rptui_ask_for_program(LLREADTEXT, _(qSwhatrpt), &fname, &fullpath
 			, programsdir, ".ll", picklist)) {
 			if (fname)  {
@@ -466,7 +466,7 @@ remove_tables (PACTX pactx)
 static BOOLEAN
 find_program (STRING fname, STRING localdir, STRING *pfull,BOOLEAN include)
 {
-	STRING programsdir = getoptstr("LLPROGRAMS", ".");
+	STRING programsdir = getlloptstr("LLPROGRAMS", ".");
 	FILE * fp = 0;
 	ZSTR zstr=zs_new();
 	BOOLEAN rtn=FALSE;
@@ -672,6 +672,17 @@ interpret (PNODE node, SYMTAB stab, PVALUE *pval)
 				return irc;
 			}
 			break;
+		case IFAMILYSPOUSES:
+			switch (irc = interp_familyspouses(node, stab, pval)) {
+			case INTOKAY:
+			case INTBREAK:
+				break;
+			case INTERROR:
+				goto interp_fail;
+			default:
+				return irc;
+			}
+			break;
 		case ISPOUSES:
 			switch (irc = interp_spouses(node, stab, pval)) {
 			case INTOKAY:
@@ -875,7 +886,7 @@ interpret (PNODE node, SYMTAB stab, PVALUE *pval)
 		case IRETURN:
 			if (iargs(node))
 				*pval = evaluate(iargs(node), stab, &eflg);
-			if (eflg && getoptint("FullReportCallStack", 0) > 0)
+			if (eflg && getlloptint("FullReportCallStack", 0) > 0)
 				prog_error(node, "in return statement");
 			return INTRETURN;
 		default:
@@ -888,7 +899,7 @@ interpret (PNODE node, SYMTAB stab, PVALUE *pval)
 	return TRUE;
 
 interp_fail:
-	if (getoptint("FullReportCallStack", 0) > 0) {
+	if (getlloptint("FullReportCallStack", 0) > 0) {
 		llwprintf("e%d: ", iline(node)+1);
 		debug_show_one_pnode(node);
 		llwprintf("\n");
@@ -943,6 +954,54 @@ aleave:
 	unlock_cache(fcel);
 	return irc;
 }
+/*========================================+
+ * interp_familyspouses -- Interpret familyspouses loop
+ *  usage: familyspouses(FAM,INDI_V,INT_V) {...}
+ *=======================================*/
+INTERPTYPE
+interp_familyspouses (PNODE node, SYMTAB stab, PVALUE *pval)
+{
+	BOOLEAN eflg = FALSE;
+	INT nspouse;
+	CACHEEL fcel, cel;
+	INTERPTYPE irc;
+	PVALUE val;
+	NODE fam = (NODE) eval_fam(iloopexp(node), stab, &eflg, &fcel);
+	if (eflg) {
+		prog_error(node, nonfamx, "family spouses", "1");
+		return INTERROR;
+	}
+	if (fam && nestr(ntag(fam), "FAM")) {
+		prog_error(node, badargx, "family spouses", "1");
+		return INTERROR;
+	}
+	if (!fam) return INTOKAY;
+	lock_cache(fcel);
+	FORFAMSPOUSES(fam, spouse, nspouse)
+		val = create_pvalue_from_indi(spouse);
+		insert_symtab(stab, ichild(node), val);
+		insert_symtab(stab, inum(node), create_pvalue_from_int(nspouse));
+		/* val should be real person, because it came from FORFAMSPOUSES */
+		cel = pvalue_to_cel(val);
+		lock_cache(cel);
+		irc = interpret((PNODE) ibody(node), stab, pval);
+		unlock_cache(cel);
+		switch (irc) {
+		case INTCONTINUE:
+		case INTOKAY:
+			goto aloop;
+		default:
+			goto aleave;
+		}
+aloop:	;
+	ENDFAMSPOUSES
+	irc = INTOKAY;
+aleave:
+	delete_symtab_element(stab, ichild(node));
+	delete_symtab_element(stab, inum(node));
+	unlock_cache(fcel);
+	return irc;
+}
 /*==============================================+
  * interp_spouses -- Interpret spouse loop
  *  usage: spouses(INDI,INDI_V,FAM_V,INT_V) {...}
@@ -1341,7 +1400,7 @@ interp_forindi (PNODE node, SYMTAB stab, PVALUE *pval)
 		lock_cache(icel); /* keep current indi in cache during loop body */
 		/* set loop variables */
 		insert_symtab(stab, ielement(node), ival);
-		insert_symtab(stab, inum(node), create_pvalue_from_int(count));
+		insert_symtab(stab, inum(node), create_pvalue_from_int(icount));
 		/* execute loop body */
 		irc = interpret((PNODE) ibody(node), stab, pval);
 		unlock_cache(icel);
@@ -1390,7 +1449,7 @@ interp_forsour (PNODE node, SYMTAB stab, PVALUE *pval)
 		lock_cache(scel); /* keep current source in cache during loop body */
 		/* set loop variables */
 		insert_symtab(stab, ielement(node), sval);
-		insert_symtab(stab, inum(node), create_pvalue_from_int(count));
+		insert_symtab(stab, inum(node), create_pvalue_from_int(scount));
 		/* execute loop body */
 		irc = interpret((PNODE) ibody(node), stab, pval);
 		unlock_cache(scel);
@@ -1437,7 +1496,7 @@ interp_foreven (PNODE node, SYMTAB stab, PVALUE *pval)
 		lock_cache(ecel); /* keep current event in cache during loop body */
 		/* set loop variables */
 		insert_symtab(stab, ielement(node), eval);
-		insert_symtab(stab, inum(node), create_pvalue_from_int(count));
+		insert_symtab(stab, inum(node), create_pvalue_from_int(ecount));
 		/* execute loop body */
 		irc = interpret((PNODE) ibody(node), stab, pval);
 		unlock_cache(ecel);
@@ -1484,7 +1543,7 @@ interp_forothr (PNODE node, SYMTAB stab, PVALUE *pval)
 		lock_cache(xcel); /* keep current source in cache during loop body */
 		/* set loop variables */
 		insert_symtab(stab, ielement(node), xval);
-		insert_symtab(stab, inum(node), create_pvalue_from_int(count));
+		insert_symtab(stab, inum(node), create_pvalue_from_int(xcount));
 		/* execute loop body */
 		irc = interpret((PNODE) ibody(node), stab, pval);
 		unlock_cache(xcel);
@@ -1529,7 +1588,7 @@ interp_forfam (PNODE node, SYMTAB stab, PVALUE *pval)
 		fcount++;
 		lock_cache(fcel);
 		insert_symtab(stab, ielement(node), fval);
-		insert_symtab(stab, inum(node), create_pvalue_from_int(count));
+		insert_symtab(stab, inum(node), create_pvalue_from_int(fcount));
 		irc = interpret((PNODE) ibody(node), stab, pval);
 		unlock_cache(fcel);
 		switch (irc) {
@@ -1989,7 +2048,7 @@ vprog_error (PNODE node, STRING fmt, va_list args)
 	static char msgbuff[100];
 	if (rpt_cancelled)
 		return _("Report cancelled");
-	rptfile = getoptstr("ReportLog", NULL);
+	rptfile = getlloptstr("ReportLog", NULL);
 	if (node) {
 		STRING fname = irptinfo(node)->fullpath;
 		INT lineno = iline(node)+1;
@@ -2030,7 +2089,7 @@ vprog_error (PNODE node, STRING fmt, va_list args)
 			fclose(fp);
 		}
 	}
-	if ((num = getoptint("PerErrorDelay", 0)))
+	if ((num = getlloptint("PerErrorDelay", 0)))
 		sleep(num);
 	zs_free(&zstr);
 	return msgbuff;
@@ -2116,7 +2175,7 @@ pa_handle_include (PACTX pactx, PNODE node)
 	newfname = pvalue_to_string(pval);
 	
 	/* if it is relative, get local path to give to find_program */
-	if (!is_absolute_path(newfname)) {
+	if (!is_path(newfname)) {
 		localpath = zs_str(irptinfo(node)->localpath);
 	}
 
