@@ -145,6 +145,7 @@ struct tag_pnode {
 #define IMOTHS      29   /* mothers loop */
 #define IFAMCS      30   /* parents loop */
 #define INOTES      31   /* notes loop */
+#define IFAMILYSPOUSES 32   /* family spouses loop */
 #define IFREED      99   /* returned to free list */
 
 /* pnode flags */
@@ -220,6 +221,7 @@ INTERPTYPE interp_families(PNODE, SYMTAB, PVALUE*);
 INTERPTYPE interp_fathers(PNODE, SYMTAB, PVALUE*);
 INTERPTYPE interp_mothers(PNODE, SYMTAB, PVALUE*);
 INTERPTYPE interp_parents(PNODE, SYMTAB, PVALUE*);
+INTERPTYPE interp_familyspouses(PNODE, SYMTAB, PVALUE*);
 INTERPTYPE interp_fornotes(PNODE, SYMTAB, PVALUE*);
 INTERPTYPE interp_fornodes(PNODE, SYMTAB, PVALUE*);
 INTERPTYPE interp_forindi(PNODE, SYMTAB, PVALUE*);
@@ -238,210 +240,219 @@ INTERPTYPE interp_traverse(PNODE, SYMTAB, PVALUE*);
 /* Language Keyword Implementations                                     */
 /************************************************************************/
 
-PVALUE ___alpha(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __add(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __addnode(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __addtoset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __ancestorset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __and(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __bapt(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __birt(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __buri(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __bytecode(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __capitalize(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __card(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __child(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __childset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __choosechild(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __choosefam(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __chooseindi(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __choosespouse(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __choosesubset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __clear(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __col(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __complexdate(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __complexformat(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __complexpic(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __concat(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __convertcode(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __copyfile(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __createnode(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __d(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __database(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __date(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __dateformat(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __datepic(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __dayformat(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __deat(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __debug(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __decr(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __deletefromset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __dequeue(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __descendentset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __detachnode(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __difference(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __div(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __dup(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __empty(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __enqueue(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __eq(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __eqstr(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __exp(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __extractdate(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __extractdatestr(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __extractnames(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __extractplaces(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __extracttokens(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __f(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __fam(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __fath(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __female(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __firstchild(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __firstfam(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __firstindi(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __float(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __fnode(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __free(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __free(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __fullname(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __ge(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __gengedcom(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __gengedcomweak(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __gengedcomstrong(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __genindiset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __getcol(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __getel(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __getfam(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __getindi(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __getindiset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __getint(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __getproperty(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __dereference(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __getstr(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __gettext(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __gettoday(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __givens(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __gt(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __heapused(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __husband(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __incr(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __index(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __indi(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __indiset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __inlist(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __inlist(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __inode(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __insert(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __inset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __int(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __intersect(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __key(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __keysort(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __lastchild(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __lastfam(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __lastindi(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __le(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __length(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __lengthset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __level(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __linemode(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __list(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __lock(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __long(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __lookup(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __lower(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __lt(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __male(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __marr(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __menuchoose(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __mod(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __monthformat(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __moth(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __mul(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __name(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __namesort(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __nchildren(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __ne(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __neg(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __nestr(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __newfile(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __nextfam(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __nextindi(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __nextsib(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __nfamilies(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __nl(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __not(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __nspouses(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __or(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __ord(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __eraformat(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __outfile(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __pagemode(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __pageout(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __parent(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __parents(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __parentset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __place(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __pn(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __pop(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __pos(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __prevfam(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __previndi(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __prevsib(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __print(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __program(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __push(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __pvalue(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __qt(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __reference(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __requeue(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __rjustify(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __roman(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __rot(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __row(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __rsort(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __save(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __savenode(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __set(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __setel(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __setlocale(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __sex(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __short(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __sibling(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __siblingset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __sort(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __soundex(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __space(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __spouseset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __stddate(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __strcmp(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __strlen(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __strsoundex(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __strtoint(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __sub(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __substring(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __surname(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __runsystem(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __table(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __tag(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __test(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __titl(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __titlcase(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __trim(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __trimname(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __union(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __uniqueset(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __unlock(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __upper(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __value(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __valuesort(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __version(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __wife(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __writefam(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __writeindi(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __xref(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __year(PNODE, SYMTAB, BOOLEAN *);
-PVALUE __yearformat(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_alpha(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_add(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_addnode(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_addtoset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_ancestorset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_and(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_arccos(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_arcsin(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_arctan(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_bapt(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_birt(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_buri(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_bytecode(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_capitalize(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_card(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_child(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_childset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_choosechild(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_choosefam(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_chooseindi(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_choosespouse(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_choosesubset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_clear(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_col(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_cos(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_complexdate(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_complexformat(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_complexpic(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_concat(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_convertcode(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_copyfile(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_createnode(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_d(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_database(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_date(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_dateformat(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_datepic(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_dayformat(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_deat(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_debug(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_decr(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_deg2dms(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_deletefromset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_dequeue(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_descendentset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_detachnode(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_difference(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_div(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_dms2deg(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_dup(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_empty(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_enqueue(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_eq(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_eqstr(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_exp(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_extractdate(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_extractdatestr(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_extractnames(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_extractplaces(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_extracttokens(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_f(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_fam(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_fath(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_female(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_firstchild(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_firstfam(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_firstindi(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_float(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_fnode(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_free(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_free(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_fullname(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_ge(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_gengedcom(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_gengedcomweak(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_gengedcomstrong(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_genindiset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_getcol(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_getel(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_getfam(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_getindi(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_getindiset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_getint(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_getproperty(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_dereference(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_getstr(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_gettext(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_gettoday(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_givens(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_gt(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_heapused(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_husband(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_incr(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_index(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_indi(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_indiset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_inlist(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_inlist(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_inode(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_insert(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_inset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_int(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_intersect(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_key(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_keysort(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_lastchild(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_lastfam(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_lastindi(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_le(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_length(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_lengthset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_level(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_linemode(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_list(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_lock(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_long(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_lookup(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_lower(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_lt(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_male(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_marr(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_menuchoose(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_mod(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_monthformat(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_moth(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_mul(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_name(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_namesort(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_nchildren(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_ne(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_neg(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_nestr(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_newfile(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_nextfam(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_nextindi(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_nextsib(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_nfamilies(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_nl(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_not(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_nspouses(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_or(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_ord(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_eraformat(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_outfile(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_pagemode(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_pageout(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_parent(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_parents(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_parentset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_place(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_pn(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_pop(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_pos(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_prevfam(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_previndi(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_prevsib(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_print(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_program(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_push(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_pvalue(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_qt(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_reference(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_requeue(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_rjustify(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_roman(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_rot(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_row(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_rsort(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_save(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_savenode(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_set(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_setel(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_setlocale(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_sex(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_short(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_sibling(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_siblingset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_sin(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_sort(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_soundex(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_space(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_spdist(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_spouseset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_stddate(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_strcmp(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_strlen(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_strsoundex(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_strtoint(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_sub(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_substring(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_surname(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_runsystem(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_table(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_tag(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_tan(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_test(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_titl(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_titlcase(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_trim(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_trimname(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_union(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_uniqueset(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_unlock(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_upper(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_value(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_valuesort(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_version(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_wife(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_writefam(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_writeindi(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_xref(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_year(PNODE, SYMTAB, BOOLEAN *);
+PVALUE llrpt_yearformat(PNODE, SYMTAB, BOOLEAN *);
 
 /* **************************************************************** */
 
@@ -527,6 +538,7 @@ void pa_handle_global(STRING iden);
 void pa_handle_option(PVALUE optval);
 void pa_handle_proc(PACTX pactx, CNSTRING procname, PNODE nd_args, PNODE nd_body);
 void pa_handle_require(PACTX pactx, PNODE node);
+PNODE familyspouses_node(PACTX pactx, PNODE, STRING, STRING, PNODE);
 PNODE parents_node(PACTX pactx, PNODE, STRING, STRING, PNODE);
 PNODE proc_node(PACTX pactx, CNSTRING, PNODE, PNODE);
 void prog_error(PNODE, STRING, ...);
