@@ -29,30 +29,25 @@
  *   3.0.3 - 25 Aug 95
  *===========================================================*/
 
-#include "sys_inc.h"
-
 #include "llstdlib.h"
+/* llstdlib.h pulls in standard.h, config.h, sys_inc.h */
 #include "table.h"
 #include "translat.h"
 #include "gedcom.h"
-#include "cache.h"
 #include "interpi.h"
-#include "indiseq.h"
 #include "liflines.h"
 #include "lloptions.h"
 #include "feedback.h" /* call_system_cmd */
 #include "zstr.h"
 #include "array.h"
-#include "object.h"
-
 
 /*********************************************
  * external/imported variables
  *********************************************/
 
 extern STRING qSnotonei, qSifonei;
-extern STRING nonint1,nonintx,nonstr1,nonstrx,nonlstx,nonvarx,nonnodx;
-extern STRING nonind1,nonindx,nonfam1,nonrecx,nonnod1,nonnodx;
+extern STRING nonint1,nonintx,nonflox,nonstr1,nonstrx,nonlstx,nonvarx;
+extern STRING nonind1,nonindx,nonfam1,nonrecx,nonnod1,nonnodx,badtrig;
 
 /*********************************************
  * local function prototypes
@@ -61,12 +56,12 @@ extern STRING nonind1,nonindx,nonfam1,nonrecx,nonnod1,nonnodx;
 /* alphabetical */
 static STRING allocsubstring(STRING s, INT i, INT j);
 static void compute_pi(STRING pi, STRING sub);
+static double deg2rad(double deg);
 static INT ll_index(STRING str, STRING sub, INT num);
 static INT kmp_search(STRING pi, STRING str, STRING sub, INT num);
 static void makestring(PVALUE val, STRING str, INT len, BOOLEAN *eflg);
+static double rad2deg(double rad);
 static STRING rightjustify(STRING str, INT len);
-static PVALUE sortimpl(PNODE node, SYMTAB stab, BOOLEAN *eflg, BOOLEAN fwd);
-static INT sortpair_bin(const void * el1, const void * el2);
 
 /*********************************************
  * local variables
@@ -80,11 +75,11 @@ BOOLEAN prog_trace = FALSE;
  *********************************************/
 
 /*=============================================================+
- * __extractnames -- Extract name parts from person or NAME node
- *   usage: extractnames(NODE, LIST, VARB, VARB) -> VOID
+ * llrpt_extractnames -- Extract name parts from person or NAME node
+ * usage: extractnames(NODE, LIST, VARB, VARB) -> VOID
  *============================================================*/
 PVALUE
-__extractnames (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_extractnames (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	LIST list=0;
 	STRING str, str2;
@@ -146,11 +141,11 @@ __extractnames (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return NULL;
 }
 /*==============================================================+
- * __extractplaces -- Extract place parts from event or PLAC NODE
- *   usage: extractplaces(NODE, LIST, VARB) -> VOID
+ * llrpt_extractplaces -- Extract place parts from event or PLAC NODE
+ * usage: extractplaces(NODE, LIST, VARB) -> VOID
  *=============================================================*/
 PVALUE
-__extractplaces (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_extractplaces (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	LIST list=0, temp=0;
 	STRING str, str2;
@@ -199,11 +194,11 @@ __extractplaces (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return NULL;
 }
 /*==========================================================+
- * __extracttokens -- Extract tokens from a STRING value
- *   usage: extracttokens(STRING, LIST, VARB, STRING) -> VOID
+ * llrpt_extracttokens -- Extract tokens from a STRING value
+ * usage: extracttokens(STRING, LIST, VARB, STRING) -> VOID
  *=========================================================*/
 PVALUE
-__extracttokens (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_extracttokens (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	LIST list=0, temp=0;
 	INT len;
@@ -253,11 +248,11 @@ __extracttokens (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return NULL;
 }
 /*===================================+
- * __database -- Return database name
- *   usage: database([BOOL]) -> STRING
+ * llrpt_database -- Return database name
+ * usage: database([BOOL]) -> STRING
  *==================================*/
 PVALUE
-__database (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_database (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	extern STRING readpath;
 	BOOLEAN full = FALSE;
@@ -276,11 +271,11 @@ __database (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	    (full ? readpath : lastpathname(readpath)));
 }
 /*===========================================+
- * __index -- Find nth occurrence of substring
- *   usage: index(STRING, STRING, INT) -> INT
+ * llrpt_index -- Find nth occurrence of substring
+ * usage: index(STRING, STRING, INT) -> INT
  *==========================================*/
 PVALUE
-__index (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_index (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	INT num;
 	PNODE arg = (PNODE) iargs(node);
@@ -311,11 +306,11 @@ __index (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return val3;
 }
 /*==============================================+
- * __substring -- Find substring of string.
- *   usage: substring(STRING, INT, INT) -> STRING
+ * llrpt_substring -- Find substring of string.
+ * usage: substring(STRING, INT, INT) -> STRING
  *=============================================*/
 PVALUE
-__substring (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_substring (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	INT lo, hi;
 	PNODE arg = (PNODE) iargs(node);
@@ -453,11 +448,11 @@ allocsubstring (STRING s, INT i, INT j)
 	}
 }
 /*===============================================
- * chooseindi -- Have user choose person from set
- *   usage: chooseindi(SET) -> INDI
+ * llrpt_chooseindi -- Have user choose person from set
+ * usage: chooseindi(SET) -> INDI
  *=============================================*/
 PVALUE
-__chooseindi (PNODE node, SYMTAB stab, BOOLEAN * eflg)
+llrpt_chooseindi (PNODE node, SYMTAB stab, BOOLEAN * eflg)
 {
 	NODE indi=0;
 	INDISEQ seq=0;
@@ -474,11 +469,11 @@ __chooseindi (PNODE node, SYMTAB stab, BOOLEAN * eflg)
 	return create_pvalue_from_indi(indi);
 }
 /*================================================+
- * choosesubset -- Have user choose subset from set
- *   usage: choosesubset(SET) -> SET
+ * llrpt_choosesubset -- Have user choose subset from set
+ * usage: choosesubset(SET) -> SET
  *===============================================*/
 PVALUE
-__choosesubset (PNODE node, SYMTAB stab, BOOLEAN * eflg)
+llrpt_choosesubset (PNODE node, SYMTAB stab, BOOLEAN * eflg)
 {
 	STRING msg;
 	INDISEQ newseq, seq;
@@ -499,11 +494,11 @@ __choosesubset (PNODE node, SYMTAB stab, BOOLEAN * eflg)
 	return create_pvalue_from_seq(newseq);
 }
 /*=========================================================+
- * choosechild -- Have user choose child of person or family
- *   usage: choosechild(INDI|FAM) -> INDI
+ * llrpt_choosechild -- Have user choose child of person or family
+ * usage: choosechild(INDI|FAM) -> INDI
  *========================================================*/
 PVALUE
-__choosechild (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_choosechild (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	INT type;
 	CNSTRING key=0;
@@ -541,11 +536,11 @@ __choosechild (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return NULL;
 }
 /*=================================================+
- * choosespouse -- Have user choose spouse of person
- *   usage: choosespouse(INDI) -> INDI
+ * llrpt_choosespouse -- Have user choose spouse of person
+ * usage: choosespouse(INDI) -> INDI
  *================================================*/
 PVALUE
-__choosespouse (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_choosespouse (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	NODE indi = eval_indi(iargs(node), stab, eflg, NULL);
 	INDISEQ seq;
@@ -561,11 +556,11 @@ __choosespouse (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return create_pvalue_from_indi(indi); /* indi may be NULL */
 }
 /*==============================================+
- * choosefam -- Have user choose family of person
- *   usage: choosefam (INDI) -> FAM
+ * llrpt_choosefam -- Have user choose family of person
+ * usage: choosefam (INDI) -> FAM
  *=============================================*/
 PVALUE
-__choosefam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_choosefam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	NODE fam, indi = eval_indi(iargs(node), stab, eflg, NULL);
 	INDISEQ seq;
@@ -642,11 +637,11 @@ makestring (PVALUE val, STRING str, INT len, BOOLEAN *eflg)
 	}
 }
 /*===================================================+
- * menuchoose -- Have user choose from list of options
- *   usage: menuchoose (LIST [,STRING]) -> INT
+ * llrpt_menuchoose -- Have user choose from list of options
+ * usage: menuchoose (LIST [,STRING]) -> INT
  *==================================================*/
 PVALUE
-__menuchoose (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_menuchoose (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	INT i, j, len;
 	STRING msg, *strngs;
@@ -700,11 +695,11 @@ __menuchoose (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return create_pvalue_from_int(i + 1);
 }
 /*================================+
- * runsystem -- Run shell command
- *   usage: runsystem (STRING) -> VOID
+ * llrpt_runsystem -- Run shell command
+ * usage: runsystem (STRING) -> VOID
  *===============================*/
 PVALUE
-__runsystem (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_runsystem (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	STRING cmd;
 	PNODE arg = iargs(node);
@@ -718,7 +713,7 @@ __runsystem (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 		delete_pvalue(val);
 		return NULL;
 	}
-	if (!getoptint("DenySystemCalls", 0)) {
+	if (!getlloptint("DenySystemCalls", 0)) {
 		call_system_cmd(cmd);
 	} else {
 		/* llwprintf("Suppressing system(%s) call", cmd); */
@@ -727,11 +722,11 @@ __runsystem (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return NULL;
 }
 /*============================================+
- * firstindi -- Return first person in database
- *   usage: firstindi() -> INDI
+ * llrpt_firstindi -- Return first person in database
+ * usage: firstindi() -> INDI
  *===========================================*/
 PVALUE
-__firstindi (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_firstindi (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	node=node; /* unused */
 	stab=stab; /* unused */
@@ -739,11 +734,11 @@ __firstindi (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return create_pvalue_from_indi_keynum(xref_firsti());
 }
 /*==========================================+
- * nextindi -- Return next person in database
- *   usage: nextindi(INDI) -> INDI
+ * llrpt_nextindi -- Return next person in database
+ * usage: nextindi(INDI) -> INDI
  *=========================================*/
 PVALUE
-__nextindi (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_nextindi (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	PNODE arg = iargs(node);
 	NODE indi = eval_indi(arg, stab, eflg, NULL);
@@ -761,11 +756,11 @@ __nextindi (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return create_pvalue_from_indi_keynum(i);
 }
 /*==============================================+
- * previndi -- Return previous person in database
- *   usage: previndi(INDI) -> INDI
+ * llrpt_previndi -- Return previous person in database
+ * usage: previndi(INDI) -> INDI
  *=============================================*/
 PVALUE
-__previndi (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_previndi (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	PNODE arg = iargs(node);
 	NODE indi = eval_indi(arg, stab, eflg, NULL);
@@ -783,11 +778,11 @@ __previndi (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return create_pvalue_from_indi_keynum(i);
 }
 /*===========================================
- * lastindi -- Return last person in database
- *   usage: lastindi() -> INDI
+ * llrpt_lastindi -- Return last person in database
+ * usage: lastindi() -> INDI
  *=========================================*/
 PVALUE
-__lastindi (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_lastindi (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	node=node; /* unused */
 	stab=stab; /* unused */
@@ -795,11 +790,11 @@ __lastindi (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return create_pvalue_from_indi_keynum(xref_lasti());
 }
 /*===========================================+
- * firstfam -- Return first family in database
- *   usage: firstfam() -> FAM
+ * llrpt_firstfam -- Return first family in database
+ * usage: firstfam() -> FAM
  *==========================================*/
 PVALUE
-__firstfam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_firstfam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	node=node; /* unused */
 	stab=stab; /* unused */
@@ -807,11 +802,11 @@ __firstfam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return create_pvalue_from_fam_keynum(xref_firstf());
 }
 /*=========================================+
- * nextfam -- Return next family in database
- *   usage: nextfam(FAM) -> FAM
+ * llrpt_nextfam -- Return next family in database
+ * usage: nextfam(FAM) -> FAM
  *========================================*/
 PVALUE
-__nextfam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_nextfam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	PNODE arg = iargs(node);
 	NODE fam = eval_fam(arg, stab, eflg, NULL);
@@ -829,11 +824,11 @@ __nextfam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return create_pvalue_from_fam_keynum(i);
 }
 /*=============================================+
- * prevfam -- Return previous family in database
- *   usage: prevfam(FAM) -> FAM
+ * llrpt_prevfam -- Return previous family in database
+ * usage: prevfam(FAM) -> FAM
  *============================================*/
 PVALUE
-__prevfam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_prevfam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	PNODE arg = iargs(node);
 	NODE fam = eval_fam(arg, stab, eflg, NULL);
@@ -851,11 +846,11 @@ __prevfam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return create_pvalue_from_fam_keynum(i);
 }
 /*=========================================+
- * lastfam -- Return last family in database
- *   usage: lastfam() -> FAM
+ * llrpt_lastfam -- Return last family in database
+ * usage: lastfam() -> FAM
  *========================================*/
 PVALUE
-__lastfam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_lastfam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	node=node; /* unused */
 	stab=stab; /* unused */
@@ -863,13 +858,12 @@ __lastfam (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return create_pvalue_from_fam_keynum(xref_lastf());
 }
 /*=============================================+
- * __dereference -- Read top node of GEDCOM record from database
- *  usage: dereference(STRING) -> NODE
- *  usage: dereference(STRING) -> NODE
- *  NOTE: persons and families NOT cached!
+ * llrpt_dereference -- Read top node of GEDCOM record from database
+ * usage: dereference(STRING) -> NODE
+ * NOTE: persons and families NOT cached!
  *============================================*/
 PVALUE
-__dereference (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_dereference (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	STRING key;
 	PNODE arg = iargs(node);
@@ -896,11 +890,11 @@ __dereference (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return val;
 }
 /*================================================+
- * reference -- Check if STRING is record reference
- *  usage: reference(STRING) -> BOOLEAN
+ * llrpt_reference -- Check if STRING is record reference
+ * usage: reference(STRING) -> BOOLEAN
  *===============================================*/
 PVALUE
-__reference (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_reference (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	STRING key;
 	BOOLEAN rc;
@@ -917,11 +911,11 @@ __reference (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return val;
 }
 /*========================================+
- * rjustify -- Right justify string value
- *   usage: rjustify(STRING, INT) -> STRING
+ * llrpt_rjustify -- Right justify string value
+ * usage: rjustify(STRING, INT) -> STRING
  *=======================================*/
 PVALUE
-__rjustify (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_rjustify (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	PNODE sarg = (PNODE) iargs(node);
 	PNODE larg = inext(sarg);
@@ -968,11 +962,11 @@ rightjustify (STRING str, INT len)
 	return new;
 }
 /*=========================================+
- * __lock -- Lock person or family in memory
- *   usage: lock(INDI|FAM) -> VOID
+ * llrpt_lock -- Lock person or family in memory
+ * usage: lock(INDI|FAM) -> VOID
  *========================================*/
 PVALUE
-__lock (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_lock (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	INT type;
 	CACHEEL cel;
@@ -991,11 +985,11 @@ __lock (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return NULL;
 }
 /*===============================================+
- * __unlock -- Unlock person or family from memory
- *   usage: unlock(INDI|FAM) -> VOID
+ * llrpt_unlock -- Unlock person or family from memory
+ * usage: unlock(INDI|FAM) -> VOID
  *==============================================*/
 PVALUE
-__unlock (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_unlock (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	INT type;
 	CACHEEL cel;
@@ -1013,11 +1007,11 @@ __unlock (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return NULL;
 }
 /*==========================================+
- * __savenode -- Save GEDCOM tree permanently
- *   usage: savenode(NODE) -> NODE
+ * llrpt_savenode -- Save GEDCOM tree permanently
+ * usage: savenode(NODE) -> NODE
  *=========================================*/
 PVALUE
-__savenode (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_savenode (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	NODE line;
 	PNODE arg = iargs(node);
@@ -1033,11 +1027,11 @@ __savenode (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return val;
 }
 /*===================================================+
- * __genindiset -- Generate set of persons from a name
- *   usage: genindiset(STRING, SET) -> VOID
+ * llrpt_genindiset -- Generate set of persons from a name
+ * usage: genindiset(STRING, SET) -> VOID
  *==================================================*/
 PVALUE
-__genindiset (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_genindiset (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	PNODE arg = (PNODE) iargs(node);
 	STRING name;
@@ -1064,13 +1058,12 @@ __genindiset (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	assign_iden(stab, iident(arg), seqval);
 	return NULL;
 }
-/*POINT*/
 /*================================================+
- * __version -- Return the LifeLines version string
- *   usage: version() -> STRING
+ * llrpt_version -- Return the LifeLines version string
+ * usage: version() -> STRING
  *===============================================*/
 PVALUE
-__version (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_version (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	node=node; /* unused */
 	stab=stab; /* unused */
@@ -1078,11 +1071,11 @@ __version (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return create_pvalue_from_string(get_lifelines_version(120));
 }
 /*========================================+
- * __pvalue -- Show a PVALUE -- Debug routine
- *   usage: pvalue(ANY) -> STRING
+ * llrpt_pvalue -- Show a PVALUE -- Debug routine
+ * usage: pvalue(ANY) -> STRING
  *=======================================*/
 PVALUE
-__pvalue (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_pvalue (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	PVALUE val = evaluate(iargs(node), stab, eflg);
 	ZSTR zstr;
@@ -1102,22 +1095,22 @@ __pvalue (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return val;
 }
 /*============================================+
- * __program -- Returns name of current program
- *   usage: program() -> STRING
+ * llrpt_program -- Returns name of current program
+ * usage: program() -> STRING
  *===========================================*/
 PVALUE
-__program (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_program (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	stab=stab; /* unused */
 	eflg=eflg; /* unused */
 	return create_pvalue_from_string(irptinfo(node)->fullpath);
 }
 /*============================================+
- * __debug -- Turn on/off programming debugging
- *   usage: debug(BOOLEAN) -> VOID
+ * llrpt_debug -- Turn on/off programming debugging
+ * usage: debug(BOOLEAN) -> VOID
  *===========================================*/
 PVALUE
-__debug (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_debug (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	PVALUE val = eval_and_coerce(PBOOL, iargs(node), stab, eflg);
 	prog_trace = pvalue_to_bool(val);
@@ -1125,11 +1118,11 @@ __debug (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return NULL;
 }
 /*========================================
- * __getproperty -- Return property string
- *   usage: getproperty(STRING) -> STRING
+ * llrpt_getproperty -- Return property string
+ * usage: getproperty(STRING) -> STRING
  *======================================*/
 PVALUE
-__getproperty(PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_getproperty(PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
 	PNODE arg = iargs(node);
 	PVALUE val = eval_and_coerce(PSTRING, arg, stab, eflg);
@@ -1145,215 +1138,296 @@ __getproperty(PNODE node, SYMTAB stab, BOOLEAN *eflg)
 	return val;
 }
 /*========================================
- * sort_array_by_array -- sort first array of pvalues
- *  by comparing keys in second array of pvalues
+ * deg2rad -- trigonometric conversion: degrees to radians
+ * Helper function since C trig functions expect radians
  *======================================*/
-struct array_by_pvarray_info {
-	ARRAY arr_vals;
-	ARRAY arr_keys;
-};
-#if UNUSED_CODE
-static INT
-obj_lookup_comparator (OBJECT *pobj1, OBJECT *pobj2, VPTR param)
+static double
+deg2rad (double deg)
 {
-	struct array_by_pvarray_info * info = (struct array_by_pvarray_info *)param;
-	if (info->arr_keys) {
-		int i1 = pobj1 - (OBJECT *)&AData(info->arr_vals)[0];
-		int i2 = pobj2 - (OBJECT *)&AData(info->arr_vals)[0];
-		PVALUE val1 = AData(info->arr_keys)[i1];
-		PVALUE val2 = AData(info->arr_keys)[i2];
-		return pvalues_collate(val1, val2);
-	} else {
-		PVALUE val1 = (PVALUE)(*pobj1);
-		PVALUE val2 = (PVALUE)(*pobj2);
-		return pvalues_collate(val1, val2);
-	}
+  return ((fmod(deg,360.0))/180.0*M_PI);
 }
-#endif
 /*========================================
- * sortimpl -- sort first container [using second container as keys]
- * This implements __sort and __rsort.
+ * rad2deg -- trigonometric conversion: radians to degrees
+ * Helper function since C trig functions return radians
  *======================================*/
-typedef struct tag_sortpair {
-	PVALUE value;
-	PVALUE key;
-} *SORTPAIR;
-#if UNUSED_CODE
-/* comparison fnc to use with our partition_sort, commented out below */
-static INT
-sortpaircmp (SORTEL el1, SORTEL el2, VPTR param)
+static double
+rad2deg (double rad)
 {
-	SORTPAIR sp1 = (SORTPAIR)el1;
-	SORTPAIR sp2 = (SORTPAIR)el2;
-	return pvalues_collate(sp1->key, sp2->key);
+  return (fmod((rad/M_PI*180.0),360.0));
 }
-#endif
-static INT
-sortpair_bin (const void * el1, const void * el2)
+/*========================================
+ * llrpt_dms2deg -- convert degrees in DMS format to decimal degrees
+ * usage: dms2deg(INT, INT, INT, VARB) -> VOID
+ *======================================*/
+PVALUE
+llrpt_dms2deg (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
-	SORTPAIR sp1 = *(SORTPAIR *)el1;
-	SORTPAIR sp2 = *(SORTPAIR *)el2;
-	return pvalues_collate(sp1->key, sp2->key);
-}
-static PVALUE
-sortimpl (PNODE node, SYMTAB stab, BOOLEAN *eflg, BOOLEAN fwd)
-{
-	PNODE arg = (PNODE) iargs(node);
-	PVALUE val1 = eval_without_coerce(arg, stab, eflg), val2=0;
-	LIST list_vals = 0, list_keys = 0;
-	ARRAY arr_vals = 0, arr_keys = 0;
-	INT nsort = 0; /* size of array & index */
-	INT i=0;
-	struct tag_sortpair * array = 0;
-	SORTPAIR * index = 0;
-	/* 1st is values collection */
-	/* it must be a list or array */
-	if (which_pvalue_type(val1) == PLIST) {
-		list_vals = pvalue_to_list(val1);
-		nsort = length_list(list_vals);
-		array = (SORTPAIR)stdalloc(nsort * sizeof(array[0]));
-		i=0;
-		FORLIST(list_vals, el)
-			array[i++].value = (PVALUE)el;
-		ENDLIST
-	} else if (which_pvalue_type(val1) == PARRAY) {
-		arr_vals = pvalue_to_array(val1);
-		nsort = get_array_size(arr_vals);
-		array = (SORTPAIR)stdalloc(nsort * sizeof(array[0]));
-		for (i=0; i<nsort; ++i) {
-			array[i].value = (PVALUE)get_array_obj(arr_vals, i);
-		}
-	} else {
-		prog_error(node, _("First argument to (r)sort must be list or array"));
-		*eflg = TRUE;
-		goto exit_sort;
-	}
-	/* (optional) 2nd argument is keys collection */
-	/* we use the keys to collate */
-	/* (if keys collection not provided, we collate on values) */
-	arg = inext(arg);
-	if (arg) {
-		val2 = eval_without_coerce(arg, stab, eflg);
-		if (which_pvalue_type(val2) == PLIST) {
-			list_keys = pvalue_to_list(val2);
-			if (nsort != length_list(list_keys)) {
-				prog_error(node, _("Arguments to (r)sort must be of same size"));
-				*eflg = TRUE;
-				goto exit_sort;
-			}
-			i=0;
-			FORLIST(list_keys, el)
-				array[i++].key = (PVALUE)el;
-			ENDLIST
-		} else if (which_pvalue_type(val2) == PARRAY) {
-			arr_keys = pvalue_to_array(val2);
-			if (nsort != get_array_size(arr_keys)) {
-				prog_error(node, _("Arguments to (r)sort must be of same size"));
-				*eflg = TRUE;
-				goto exit_sort;
-			}
-			for (i=0; i<nsort; ++i) {
-				PVALUE val = (PVALUE)get_array_obj(arr_keys, i);
-				array[i].key = val;
-			}
-		} else {
-			prog_error(node, _("Second argument to (r)sort must be list or array"));
-			*eflg = TRUE;
-			return NULL;
-		}
-	}
-	if (!arr_keys && !list_keys) {
-		/* no keys collection (1st argument), */
-		/* so sort directly on values collection (2nd argument) */
-		for (i=0; i<nsort; ++i) {
-			array[i].key = array[i].value;
-		}
-	}
-	index = (SORTPAIR *)stdalloc(nsort * sizeof(index[0]));
-	for (i=0; i<nsort; ++i) {
-		index[i] = &array[i];
+	PNODE arg1 = (PNODE) iargs(node);
+	PNODE arg2 = inext(arg1);
+	PNODE arg3 = inext(arg2);
+	PNODE ret1 = inext(arg3);
+	FLOAT decdeg = 0.0;
+	INT neg=0;
+
+	PVALUE val = eval_and_coerce(PINT, arg1, stab, eflg);
+	if (*eflg) {
+		prog_error(node, nonflox, "dms2deg", "1");
+                return NULL;
+        }
+	decdeg += pvalue_to_int(val);
+	if (decdeg < 0) {
+		decdeg *= -1;
+		neg = 1;
 	}
 
-	qsort(index, nsort, sizeof(index[0]), sortpair_bin);
+	val = eval_and_coerce(PINT, arg2, stab, eflg);
+	if (*eflg) {
+		prog_error(node, nonflox, "dms2deg", "2");
+                return NULL;
+        }
+	decdeg += (pvalue_to_int(val) / 60.0);
 
-/* I tried speeding up the lifelines version by removing recursion and
-	doing median of three pivot, but it is still much slower than qsort
-	on MS-Windows (Perry, 2003-03-01)
-*/
-	/* partition_sort((SORTEL *)index, nsort, sortpaircmp, 0);*/
+	val = eval_and_coerce(PINT, arg3, stab, eflg);
+	if (*eflg) {
+		prog_error(node, nonflox, "dms2deg", "3");
+                return NULL;
+        }
+	decdeg += (pvalue_to_int(val) / 3600.0);
 
-	/* Now we reorder both the values (1st) and keys (2nd) collections */
-
-	/* reorder the values collection (1st argument) */
-	if (list_vals) {
-		LIST_ITER listit=0;
-		VPTR ptr=0;
-		i=0;
-		if (fwd)
-			listit = begin_list_rev(list_vals);
-		else
-			listit = begin_list(list_vals);
-		while (next_list_ptr(listit, &ptr)) {
-			change_list_ptr(listit, index[i]->value);
-			++i;
-		}
-		end_list_iter(&listit);
-	} else {
-		INT j;
-		ASSERT(arr_vals);
-		for (i=0; i<nsort; ++i) {
-			OBJECT obj = (OBJECT)index[i]->value;
-			j = (fwd ? i : nsort-i-1);
-			set_array_obj(arr_vals, j, obj);
-		}
+	if (neg == 1) {
+		decdeg *= -1;
 	}
-	if (list_keys) {
-		LIST_ITER listit=0;
-		VPTR ptr=0;
-		i=0;
-		if (fwd)
-			listit = begin_list_rev(list_keys);
-		else
-			listit = begin_list(list_keys);
-		while (next_list_ptr(listit, &ptr)) {
-			change_list_ptr(listit, index[i]->key);
-			++i;
-		}
-		end_list_iter(&listit);
-	} else if (arr_keys) {
-		INT j;
-		for (i=0; i<nsort; ++i) {
-			OBJECT obj = (OBJECT)index[i]->key;
-			j = (fwd ? i : nsort-i-1);
-			set_array_obj(arr_keys, j, obj);
-		}
-	}
-	/* else, no keys collection (2nd argument), so no 2nd reorder */
 
-exit_sort:
-	delete_pvalue(val1);
-	delete_pvalue(val2);
-	if (array)
-		stdfree(array);
-	if (index)
-		stdfree(index);
+	insert_symtab(stab, iident(ret1), create_pvalue_from_float(decdeg));
 	return NULL;
 }
 /*========================================
- * __sort -- sort first container [using second container as keys]
- *   usage: sort(LIST [, LIST]) -> VOID
+ * llrpt_deg2dms -- convert decimal degrees to DMS format
+ * usage: deg2dms(FLOAT, VARB, VARB, VARB) -> VOID
  *======================================*/
 PVALUE
-__sort (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_deg2dms (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
-	return sortimpl(node, stab, eflg, TRUE);
+	PNODE arg1 = (PNODE) iargs(node);
+	PNODE ret1 = inext(arg1);
+	PNODE ret2 = inext(ret1);
+	PNODE ret3 = inext(ret2);
+	FLOAT decdeg;
+	INT deg, min, sec, neg=0;
+
+	PVALUE val = eval_and_coerce(PFLOAT, arg1, stab, eflg);
+
+	if (*eflg) {
+		prog_error(node, nonflox, "deg2dms", "1");
+                return NULL;
+        }
+
+	decdeg = pvalue_to_float(val);
+	if (decdeg < 0) {
+		decdeg *= -1;
+		neg = 1;
+	}
+	
+	deg = (int)(decdeg);
+        decdeg -= deg;
+	decdeg *= 60;
+	min = (int)(decdeg);
+	decdeg -= min;
+	decdeg *= 60;
+	sec = (int)(decdeg);
+
+	if (neg == 1) { deg *= -1; }
+
+	insert_symtab(stab, iident(ret1), create_pvalue_from_int(deg));
+	insert_symtab(stab, iident(ret2), create_pvalue_from_int(min));
+	insert_symtab(stab, iident(ret3), create_pvalue_from_int(sec));
+	return NULL;
 }
 /*========================================
- * __rsort -- reverse sort first container [using second container as keys]
- *   usage: rsort(LIST [, LIST]) -> VOID
+ * llrpt_sin -- trigonometric SINE function
+ * usage: sin(FLOAT) -> FLOAT
  *======================================*/
 PVALUE
-__rsort (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+llrpt_sin (PNODE node, SYMTAB stab, BOOLEAN *eflg)
 {
-	return sortimpl(node, stab, eflg, FALSE);
+	PNODE arg = (PNODE) iargs(node);
+        PVALUE val = eval_and_coerce(PFLOAT, arg, stab, eflg);
+
+	if (*eflg) {
+		prog_error(node, nonflox, "sin", "1");
+                return NULL;
+        }
+
+        return create_pvalue_from_float(sin(deg2rad(pvalue_to_float(val))));
+}
+/*========================================
+ * llrpt_cos -- trigonometric COSINE function
+ * usage: cos(FLOAT) -> FLOAT
+ *======================================*/
+PVALUE
+llrpt_cos (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+{
+        PNODE arg = (PNODE) iargs(node);
+        PVALUE val = eval_and_coerce(PFLOAT, arg, stab, eflg);
+
+        if (*eflg) {
+                prog_error(node, nonflox, "cos", "1");
+                return NULL;
+        }
+
+        return create_pvalue_from_float(cos(deg2rad(pvalue_to_float(val))));
+}
+/*========================================
+ * llrpt_tan -- trigonometric TANGENT function
+ * usage: tan(FLOAT) -> FLOAT
+ *======================================*/
+PVALUE
+llrpt_tan (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+{
+        PNODE arg = (PNODE) iargs(node);
+        PVALUE val = eval_and_coerce(PFLOAT, arg, stab, eflg);
+	FLOAT val2;
+
+        if (*eflg) {
+                prog_error(node, nonflox, "tan", "1");
+                return NULL;
+        }
+
+        val2 = pvalue_to_float(val);
+
+	/* avoid SIGFPE caused by invalid input */
+	if (fmod((val2-90),180) == 0) {
+		*eflg = 1;
+		prog_error(node, badtrig, "tan", "1");
+		return NULL;
+	}
+
+        return create_pvalue_from_float(tan(deg2rad(val2)));
+}
+/*========================================
+ * llrpt_arcsin -- trigonometric inverse SINE function
+ * usage: arcsin(FLOAT) -> FLOAT
+ *======================================*/
+PVALUE
+llrpt_arcsin (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+{
+	PNODE arg = (PNODE) iargs(node);
+        PVALUE val = eval_and_coerce(PFLOAT, arg, stab, eflg);
+	FLOAT val2;
+
+	if (*eflg) {
+		prog_error(node, nonflox, "arcsin", "1");
+		return NULL;
+	}
+
+	val2 = pvalue_to_float(val);
+
+	/* avoid SIGFPE caused by invalid input */
+	if (val2 > 1.0 || val2 < -1.0) {
+		*eflg = 1;
+		prog_error(node, badtrig, "arcsin", "1");
+		return NULL;
+	}
+
+        return create_pvalue_from_float(rad2deg(asin(val2)));
+}
+/*========================================
+ * llrpt_arccos -- trigonometric inverse COSINE function
+ * usage: arccos(FLOAT) -> FLOAT
+ *======================================*/
+PVALUE
+llrpt_arccos (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+{
+        PNODE arg = (PNODE) iargs(node);
+        PVALUE val = eval_and_coerce(PFLOAT, arg, stab, eflg);
+	FLOAT val2;
+
+        if (*eflg) {
+                prog_error(node, nonflox, "arccos", "1");
+                return NULL;
+        }
+
+	val2 = pvalue_to_float(val);
+
+	/* avoid SIGFPE caused by invalid input */
+	if (val2 > 1.0 || val2 < -1.0) {
+		*eflg = 1;
+		prog_error(node, badtrig, "arccos", "1");
+		return NULL;
+	}
+
+        return create_pvalue_from_float(rad2deg(acos(val2)));
+}
+/*========================================
+ * llrpt_arctan -- trigonometric inverse TANGENT function
+ * usage: arctan(FLOAT) -> FLOAT
+ *======================================*/
+PVALUE
+llrpt_arctan (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+{
+        PNODE arg = (PNODE) iargs(node);
+        PVALUE val = eval_and_coerce(PFLOAT, arg, stab, eflg);
+
+        if (*eflg) {
+                prog_error(node, nonflox, "arctan", "1");
+                return NULL;
+        }
+
+        return create_pvalue_from_float(rad2deg(atan(pvalue_to_float(val))));
+}
+/*========================================
+ * llrpt_spdist -- spherical distance calculator
+ * usage: spdist(FLOAT, FLOAT, FLOAT, FLOAT) -> FLOAT
+ *          (lat0, lon0, lat1, lon1) -> distance (in km)
+ *======================================*/
+PVALUE
+llrpt_spdist (PNODE node, SYMTAB stab, BOOLEAN *eflg)
+{
+        PNODE arg1 = (PNODE) iargs(node);
+        PNODE arg2 = inext(arg1);
+        PNODE arg3 = inext(arg2);
+        PNODE arg4 = inext(arg3);
+	PVALUE val1, val2, val3, val4;
+	FLOAT lat0, lon0, lat1, lon1;
+	FLOAT dist, dist1, dist2;
+
+        val1 = eval_and_coerce(PFLOAT, arg1, stab, eflg);
+        if (*eflg) {
+                prog_error(node, nonflox, "spdist", "1");
+                return NULL;
+        }
+
+        val2 = eval_and_coerce(PFLOAT, arg2, stab, eflg);
+        if (*eflg) {
+                prog_error(node, nonflox, "spdist", "2");
+                return NULL;
+        }
+
+        val3 = eval_and_coerce(PFLOAT, arg3, stab, eflg);
+        if (*eflg) {
+                prog_error(node, nonflox, "spdist", "3");
+                return NULL;
+        }
+
+        val4 = eval_and_coerce(PFLOAT, arg4, stab, eflg);
+        if (*eflg) {
+                prog_error(node, nonflox, "spdist", "4");
+                return NULL;
+        }
+
+	lat0 = pvalue_to_float(val1);
+	lon0 = pvalue_to_float(val2);
+	lat1 = pvalue_to_float(val3);
+	lon1 = pvalue_to_float(val4);
+
+	/* Suggested by Patrick Texier, and verified by the following sites*/
+	/* 1) http://www.skimountaineer.com/CascadeSki/CascadeDistance.php */
+	/* 2) http://www.indo.com/distance/dist.pl */
+	/* NOTE: Must convert degrees to radians, since that's what the C */
+	/* library functions expect! */
+	dist1 = cos(deg2rad(lat0)) * cos(deg2rad(lat1)) * cos(deg2rad(lon0)-deg2rad(lon1));
+	dist2 = sin(deg2rad(lat0)) * sin(deg2rad(lat1));
+	dist = 6380.0 * acos(dist1 + dist2);
+
+        return create_pvalue_from_float(dist);
 }
