@@ -63,6 +63,7 @@ extern STRING qSfn2long,qSidkyrfn,qSduprfn;
 
 static INDISEQ ask_for_indi_list_once(STRING, INT*);
 static RECORD ask_for_any_once(STRING ttl, char ctype, ASK1Q ask1, INT *prc);
+static void make_fname_prompt(STRING fnamebuf, INT len, STRING ext);
 
 /*=====================================================
  * ask_for_fam_by_key -- Ask user to identify family by 
@@ -232,7 +233,7 @@ ask_for_file_try:
  *  for filename, depending on extension
  * Created: 2001/12/24, Perry Rapp
  *====================================*/
-void
+static void
 make_fname_prompt (STRING fnamebuf, INT len, STRING ext)
 {
 	if (ISNULL(ext)) {
@@ -288,7 +289,7 @@ ask_for_output_file (STRING mode,
  *  prc:   [OUT] result code (RC_DONE, RC_SELECT, RC_NOSELECT)
  *===============================================*/
 INDISEQ
-ask_for_indiseq (STRING ttl, char ctype, INT *prc)
+ask_for_indiseq (CNSTRING ttl, char ctype, INT *prc)
 {
 	INDISEQ seq;
 	char name[MAXPATHLEN];
@@ -308,7 +309,7 @@ ask_for_indiseq (STRING ttl, char ctype, INT *prc)
 /*============================================================
  * ask_for_any_once -- Have user identify sequence and select record
  *  ttl:   [IN]  title to present
- *  ctype: [IN]  type of record (eg, 'I') (0 for any)
+ *  ctype: [IN]  type of record (eg, 'I') (0 for any, 'B' for any preferring INDI)
  *  ask1:  [IN]  whether to present list if only one matches their desc.
  *  prc:   [OUT] result (RC_DONE, RC_SELECT, RC_NOSELECT)
  *==========================================================*/
