@@ -164,13 +164,16 @@ prompt_for_browse (RECORD * prec, INT * code, INDISEQ * pseq)
 	*pseq =0;
 
 	if (*code == BROWSE_INDI) {
-		*pseq = ask_for_indiseq(_(qSidplst), 'I', &rc);
+		/* ctype of 'B' means any type but check persons first */
+		*pseq = ask_for_indiseq(_(qSidplst), 'B', &rc);
 		if (!*pseq) return;
 		if ((len = length_indiseq(*pseq)) < 1) return;
 		if (len == 1) {
 			element_indiseq(*pseq, 0, &key, &name);
-			*prec = key_to_irecord(key);
+			*prec = qkey_to_record(key);
+			/* leaking sequence here, Perry, 2005-09-25 */
 			*pseq = NULL;
+			*code = BROWSE_UNK; /* not sure what we got above */
 		} else {
 			*code = BROWSE_LIST;
 		}
@@ -196,13 +199,17 @@ main_browse (RECORD rec1, INT code)
 {
 	RECORD rec2=0;
 	INDISEQ seq = NULL;
-	STRING key=0;
 
 	if (!rec1)
 		prompt_for_browse(&rec1, &code, &seq);
 
 	if (!rec1 && !seq) return;
 
+	/*
+	loop here handle user browsing around through
+	persons, families, references, etc, without returning
+	to main menu
+	*/
 
 	while (code != BROWSE_QUIT) {
 		switch (code) {
@@ -218,16 +225,17 @@ main_browse (RECORD rec1, INT code)
 			code = browse_2fam(&rec1, &rec2, &seq); break;
 		case BROWSE_LIST:
 			code = browse_list(&rec1, &rec2, &seq); break;
-		case BROWSE_EVEN:
 		case BROWSE_SOUR:
+		case BROWSE_EVEN:
 		case BROWSE_AUX:
 			code = browse_aux(&rec1, &rec2, &seq); break;
 		case BROWSE_UNK:
 			ASSERT(rec1);
-			key = rmvat(nxref(nztop(rec1)));
-			switch(key[0]) {
+			switch(nztype(rec1)) {
 			case 'I': code=BROWSE_INDI; break;
 			case 'F': code=BROWSE_FAM; break;
+			case 'S': code=BROWSE_SOUR; break;
+			case 'E': code=BROWSE_EVEN; break;
 			default: code=BROWSE_AUX; break;
 			}
 		}
@@ -575,7 +583,7 @@ reprocess_indi_cmd: /* so one command can forward to another */
 			}
 			break;
 		case CMD_BROWSE: 	/* Browse new list of persons */
-			seq = ask_for_indiseq(_(qSidplst), 'I', &rc);
+			seq = ask_for_indiseq(_(qSidplst), 'B', &rc);
 			if (!seq) break;
 			if (length_indiseq(seq) == 1) {
 				element_indiseq(seq, 0, &key, &name);
@@ -698,7 +706,7 @@ reprocess_indi_cmd: /* so one command can forward to another */
 		case CMD_POINTERS:	/* Browse to references */
 			if ((tmp = choose_pointer(current, _(qSnoptr), _(qSidptr))) != 0) {
 				setrecord(prec1, &tmp);
-				rtn = BROWSE_AUX;
+				rtn = BROWSE_UNK;
 				goto exitbrowse;
 			}
 			break;
@@ -977,7 +985,7 @@ prompt_add_child_check_save (NODE fam, NODE save)
 	}
 	if (save) {
 		if (keyflag)
-			if(getoptint("DisplayKeyTags", 0) > 0) {
+			if(getlloptint("DisplayKeyTags", 0) > 0) {
 				sprintf(scratch, "%s%s (i%s)", _(qSiscnew),
 				 	indi_to_name(save, 56),
 				 	rmvat(nxref(save))+1);
@@ -1182,16 +1190,20 @@ reprocess_fam_cmd: /* so one command can forward to another */
 			setrecord(&save, 0);
 			break;
 		case CMD_BROWSE: 	/* Browse to new list of persons */
-			seq = ask_for_indiseq(_(qSidplst), 'I', &rc);
+			seq = ask_for_indiseq(_(qSidplst), 'B', &rc);
 			if (!seq) break;
 			if (length_indiseq(seq) == 1) {
 				element_indiseq(seq, 0, &key, &name);
-				tmp = key_to_irecord(key);
-				setrecord(prec1, &tmp);
+				tmp = key_to_record(key);
+				setrecord(&current, &tmp);
 				remove_indiseq(seq);
 				seq=NULL;
-				rtn = BROWSE_INDI;
-				goto exitbrowse;
+				if (nztype(current) != 'F') {
+					setrecord(prec1, &current);
+					rtn = BROWSE_UNK;
+				    goto exitbrowse;
+				}
+				break;
 			}
 			*pseq = seq;
 			rtn = BROWSE_LIST;
@@ -1479,12 +1491,12 @@ static void
 load_hist_lists (void)
 {
 	/* V for visit history, planning to also have a change history */
-	INT count = getoptint("HistorySize", 20);
+	INT count = getlloptint("HistorySize", 20);
 	if (count<0 || count > 9999)
 		count = 20;
 	init_hist(&vhist, count);
 	init_hist(&chist, count);
-	if (getoptint("SaveHistory", 0)) {
+	if (getlloptint("SaveHistory", 0)) {
 		load_nkey_list("HISTV", &vhist);
 		load_nkey_list("HISTC", &chist);
 	}
@@ -1496,7 +1508,7 @@ load_hist_lists (void)
 static void
 save_hist_lists (void)
 {
-	if (!getoptint("SaveHistory", 0)) return;
+	if (!getlloptint("SaveHistory", 0)) return;
 	if (readonly || immutable) return;
 	save_nkey_list("HISTV", &vhist);
 	save_nkey_list("HISTC", &chist);
@@ -1609,7 +1621,7 @@ save_nkey_list (STRING key, struct hist * histp)
 
 	unlink(editfile);
 
-	fp = fopen(editfile, "w");
+	fp = fopen(editfile, LLWRITETEXT);
 	if (!fp) return;
 
 	/* write count first -- twice just to take up 8 bytes same as records */
@@ -1653,7 +1665,7 @@ history_record (RECORD rec, struct hist * histp)
 	NKEY nkey = nkey_zero();
 	INT prev, next, i;
 	INT count = get_hist_count(histp);
-	INT protect = getoptint("HistoryBounceSuppress", 0);
+	INT protect = getlloptint("HistoryBounceSuppress", 0);
 	if (!histp->size) return;
 	if (histp->start==-1) {
 		histp->start = histp->past_end;
