@@ -36,7 +36,6 @@
  * external variables (no header)
  *********************************************/
 
-extern STRING qSidldir,qSidldrp,qSnodbse,qScrdbse,qSiddbse;
 extern STRING qSmtitle,qSnorwandro,qSnofandl,qSbdlkar;
 extern STRING qSusgFinnOpt,qSusgFinnAlw,qSusgNorm;
 extern STRING qSbaddb,qSdefttl,qSiddefpath;
@@ -56,6 +55,7 @@ extern int opterr;
  *********************************************/
 
 static STRING usage = "";      /* usage string */
+static STRING version = "";    /* version string */
 int opt_finnish  = FALSE;      /* Finnish Language sorting order if TRUE */
 int opt_mychar = FALSE;        /* Custom character set handling (bypass libc) */
 BOOLEAN debugmode = FALSE;     /* no signal handling, so we can get coredump */
@@ -70,6 +70,7 @@ BOOLEAN progparsing = FALSE;   /* program is being parsed */
 INT     progerror = 0;         /* error count during report program */
 BOOLEAN traditional = TRUE;    /* use traditional family rules */
 BOOLEAN showusage = FALSE;     /* show usage */
+BOOLEAN showversion = FALSE;   /* show version */
 STRING  readpath_file = NULL;  /* last component of readpath */
 STRING  readpath = NULL;       /* database path used to open */
 STRING  ext_codeset = 0;       /* default codeset from locale */
@@ -84,13 +85,11 @@ static void init_browse_module(void);
 static void init_show_module(void);
 static void term_browse_module(void);
 static void term_show_module(void);
-static BOOLEAN is_unadorned_directory(STRING path);
 static void load_usage(void);
+static void load_version(void);
 static void main_db_notify(STRING db, BOOLEAN opening);
-static BOOLEAN open_or_create_database (INT alteration, STRING dbrequested, STRING *dbused);
 static void parse_arg(const char * optarg, char ** optname, char **optval);
 static void platform_init(void);
-static void show_open_error(INT dberr);
 
 /*********************************************
  * local function definitions
@@ -113,7 +112,6 @@ main (INT argc, char **argv)
 	BOOLEAN forceopen=FALSE, lockchange=FALSE;
 	char lockarg = 0; /* option passed for database lock */
 	INT alteration=0;
-	STRING dbdir = 0;
 	LIST exprogs=NULL;
 	TABLE exargs=NULL;
 	STRING progout=NULL;
@@ -141,11 +139,11 @@ main (INT argc, char **argv)
 
 	save_original_locales();
 	load_usage();
-
+	load_version();
 
 	/* Parse Command-Line Arguments */
 	opterr = 0;	/* turn off getopt's error message */
-	while ((c = getopt(argc, argv, "adkrwil:fntc:Fu:x:o:zC:I:")) != -1) {
+	while ((c = getopt(argc, argv, "adkrwil:fntc:Fu:x:o:zC:I:vh?")) != -1) {
 		switch (c) {
 		case 'c':	/* adjust cache sizes */
 			while(optarg && *optarg) {
@@ -251,7 +249,13 @@ main (INT argc, char **argv)
 		case 'C': /* specify config file */
 			configfile = optarg;
 			break;
-		case '?':
+		case 'v': /* show version */
+			showversion = TRUE;
+			goto usage;
+			break;
+		case 'h': /* show usage */
+		case '?': /* show usage */
+			showversion = TRUE;
 			showusage = TRUE;
 			goto usage;
 			break;
@@ -274,7 +278,7 @@ prompt_for_db:
 		goto finish;
 	}
 	/* setup crashlog in case init_screen fails (eg, bad menu shortcuts) */
-	crashlog = getoptstr("CrashLog_llexec", NULL);
+	crashlog = getlloptstr("CrashLog_llexec", NULL);
 	if (!crashlog) { crashlog = "Crashlog_llexec.log"; }
 	crash_setcrashlog(crashlog);
 	init_interpreter(); /* give interpreter its turn at initialization */
@@ -306,58 +310,25 @@ prompt_for_db:
 		goto usage;
 	}
 
-	dbdir = getoptstr("LLDATABASES", ".");
-	/* Get Database Name (Prompt or Command-Line) */
-	if (alldone || c <= 0) {
-		char dbname[MAXPATHLEN];
-		/* ask_for_db_filename returns static buffer, we save it below */
-		if (!ask_for_db_filename(_(qSidldir), _(qSidldrp), dbdir, dbname, sizeof(dbname))
-			|| !dbname[0]) {
-			dbrequested = NULL;
-			llwprintf(_(qSiddbse));
+	/* Open database, prompting user if necessary */
+	if (1) {
+		STRING errmsg=0;
+		if (!alldone && c>0) {
+			dbrequested = strsave(argv[optind]);
+		} else {
+			strupdate(&dbrequested, "");
+		}
+		if (!select_database(dbrequested, alteration, &errmsg)) {
+			if (errmsg) {
+				llwprintf(errmsg);
+			}
 			alldone = 0;
 			goto finish;
 		}
-		dbrequested = strsave(dbname);
-		if (eqstr(dbrequested, "?")) {
-			INT n=0;
-			LIST dblist=0, dbdesclist=0;
-			strfree(&dbrequested);
-			if ((n=get_dblist(dbdir, &dblist, &dbdesclist)) > 0) {
-				INT i;
-				i = choose_from_list(
-					_("Choose database to open")
-					, dbdesclist);
-				if (i >= 0) {
-					dbrequested = strsave(get_list_element(dblist, i+1, 0));
-				}
-				release_dblist(dblist);
-				release_dblist(dbdesclist);
-			} else {
-				llwprintf(_("No databases found in database path"));
-				goto finish;
-			}
-			if (!dbrequested) {
-				llwprintf(_(qSiddbse));
-				goto finish;
-			}
-		}
-	} else {
-		dbrequested = strsave(argv[optind]);
 	}
 
-	/* search for database */
-	/* search for file in lifelines path */
-	dbused = filepath(dbrequested, "r", dbdir, NULL, uu8);
-	if (!dbused) {
-	    dbused = strsave(dbrequested);
-	}
-
-	if (!open_or_create_database(alteration, dbrequested, &dbused))
-		goto finish;
-
 	/* Start Program */
-	if (!init_lifelines_db()) {
+	if (!init_lifelines_postdb()) {
 		llwprintf(_(qSbaddb));
 		goto finish;
 	}
@@ -396,7 +367,8 @@ finish:
 	strfree(&ext_codeset);
 
 usage:
-	/* Display Command-Line Usage Help */
+	/* Display Version and/or Command-Line Usage Help */
+	if (showversion) { puts(version); strfree(&version); }
 	if (showusage) puts(usage);
 
 	/* Exit */
@@ -438,18 +410,6 @@ shutdown_ui (BOOLEAN pause)
 {
 	pause=pause; /* unused */
 }
-/*===================================================
- * show_open_error -- Display database opening error
- *=================================================*/
-static void
-show_open_error (INT dberr)
-{
-	char buffer[256];
-	describe_dberror(dberr, buffer, ARRSIZE(buffer));
-	llwprintf(buffer);
-	llwprintf("\n");
-	sleep(5);
-}
 /*==================================================
  * platform_init -- platform specific initialization
  *================================================*/
@@ -459,81 +419,6 @@ platform_init (void)
 	/* TODO: We could do wtitle just like llines, but its declaration needs
 	to be moved somewhere more sensible for that (ie, not in curses.h!) */
 }
-/*==================================================
- * is_unadorned_directory -- is it a bare directory name,
- *  with no subdirectories ?
- * Created: 2001/01/24, Perry Rapp
- *================================================*/
-static BOOLEAN
-is_unadorned_directory (STRING path)
-{
-	for ( ; *path; path++) {
-		if (is_dir_sep(*path))
-			return FALSE;
-	}
-	return TRUE;
-}
-/*==================================================
- * open_or_create_database -- open database, prompt for
- *  creating new one if it doesn't exist
- * if fails, displays error (show_open_error) and returns 
- *  FALSE
- *  alteration:   [IN]  flags for locking, forcing open...
- *  dbrequested:  [IN]  database specified by user (usually relative)
- *  dbused:       [I/O] actual database path (may be relative)
- * If this routine creates new database, it will alter dbused
- * Created: 2001/04/29, Perry Rapp
- *================================================*/
-static BOOLEAN
-open_or_create_database (INT alteration, STRING dbrequested, STRING *dbused)
-{
-	dbrequested=dbrequested; /* unused */
-	/* Open Database */
-	if (open_database(alteration, *dbused)) {
-		return TRUE;
-	}
-	/* filter out real errors */
-	if (bterrno != BTERR_NODB && bterrno != BTERR_NOKEY)
-	{
-		show_open_error(bterrno);
-		return FALSE;
-	}
-	if (readonly || immutable || alteration)
-	{
-		llwprintf("Cannot create new database with -r, -i, -l, or -f flags.");
-		return FALSE;
-	}
-	/*
-	error was only that db doesn't exist, so lets try
-	making a new one 
-	If no database directory specified, add prefix llnewdbdir
-	*/
-	if (is_unadorned_directory(*dbused)) {
-		STRING dbpath = getoptstr("LLDATABASES", ".");
-		CNSTRING newdbdir = get_first_path_entry(dbpath);
-		STRING temp = *dbused;
-		if (newdbdir) {
-			char tempth[MAXPATHLEN];
-			newdbdir = strdup(newdbdir);
-			concat_path(newdbdir, *dbused, uu8, tempth, sizeof(tempth));
-			*dbused = strsave(tempth);
-			stdfree(temp);
-			stdfree((STRING)newdbdir);
-		}
-	}
-
-	/* Is user willing to make a new db ? */
-	if (!ask_yes_or_no_msg(_(qSnodbse), _(qScrdbse))) 
-		return FALSE;
-
-	/* try to make a new db */
-	if (create_database(*dbused))
-		return TRUE;
-
-	show_open_error(bterrno);
-	return FALSE;
-}
-
 /* Finnish language support modifies the soundex codes for names, so
  * a database created with this support is not compatible with other
  * databases. 
@@ -561,6 +446,15 @@ load_usage (void)
 	usage = _(qSusgNorm);
 #endif
 }
+
+static void
+load_version (void)
+{
+	char verbuff[80];
+	llstrncpyf(verbuff, 80, uu8, _(qSmtitle), get_lifelines_version(80));
+	version = strsave(verbuff);
+}
+
 /*==================================================
  * main_db_notify -- callback called whenever a db is
  *  opened or closed
