@@ -35,7 +35,7 @@ void advanced_family_edit(NODE);
 
 /* ask.c */
 RECORD ask_for_any(STRING ttl, CONFIRMQ, ASK1Q);
-INDISEQ ask_for_indiseq(STRING ttl, char ctype, INT *prc);
+INDISEQ ask_for_indiseq(CNSTRING ttl, char ctype, INT *prc);
 
 /* browse.c */
 RECORD choose_any_event(void);
@@ -132,6 +132,7 @@ void addmissingkeys (INT);
 int check_stdkeys (void);
 BOOLEAN scan_header(FILE * fp, TABLE metadatatab, ZSTR * zerr);
 BOOLEAN validate_gedcom(IMPORT_FEEDBACK ifeed, FILE*);
+void validate_end_import(void);
 INT validate_get_warning_count(void);
 INT xref_to_index (STRING);
 
