@@ -47,11 +47,13 @@
 extern STRING qSidcswp, qSid1csw, qSid2csw, qSid1fsw, qSid2fsw, qSidfbys, qSntprnt;
 extern STRING qSless2c, qSokcswp, qSless2f, qSokfswp, qSidfswp, qSronlye;
 extern STRING qSidcrdr, qSntchld, qSparadox;
+extern STRING qScffswp, qScfchswp;
 
 /*********************************************
  * local function prototypes
  *********************************************/
 static INT child_index(NODE child, NODE fam);
+static BOOLEAN confirm_and_swap_children_impl(NODE fam, NODE one, NODE two);
 static void swap_children_impl(NODE fam, NODE one, NODE two);
 
 /*=============================================
@@ -122,10 +124,27 @@ gotfam:
 		}
 	}
 
-	swap_children_impl(fam, one, two);
+	if (!confirm_and_swap_children_impl(fam, one, two))
+		return FALSE;
 	message(_(qSokcswp));
 	return TRUE;
 }
+/*=============================================
+ * confirm_and_swap_children_impl -- Swap input children in input family
+ *  fam:     [in] family of interest
+ *  one,two: [in] children to swap
+ * inputs assumed valie
+ * confirm then call worker
+ *===========================================*/
+static BOOLEAN
+confirm_and_swap_children_impl (NODE fam, NODE one, NODE two)
+{
+	if (!ask_yes_or_no(_(qScfchswp)))
+		return FALSE;
+
+	swap_children_impl(fam, one, two);
+	return TRUE;
+}
 /*=============================================
  * swap_children_impl -- Swap input children in input family
  *  fam:     [in] family of interest
@@ -194,7 +213,8 @@ gotfam:
 		/* swap the two existing ones */
 		NODE one = CHIL(fam);
 		NODE two = nsibling(one);
-		swap_children_impl(fam, one, two);
+		if (!confirm_and_swap_children_impl(fam, one, two))
+			return FALSE;
 		message(_(qSokcswp));
 		return TRUE;
 	}
@@ -209,7 +229,7 @@ gotfam:
 	remove_child(child, fam);
 
 	i = ask_child_order(fam, ALWAYS_PROMPT, rfmt);
-	if (i == -1) {
+	if (i == -1 || !ask_yes_or_no(_(qScfchswp))) {
 		/* must put child back if cancel */
 		add_child_to_fam(child, fam, prevorder);
 		return FALSE;
@@ -248,6 +268,7 @@ child_index (NODE child, NODE fam)
  *  indi:  [in] person
  *  prompt for indi if NULL
  *  prompt for families if person chosen has >2
+ *  Ask for yes/no confirm
  *===========================================*/
 BOOLEAN
 swap_families (RECORD irec)
@@ -302,6 +323,11 @@ swap_families (RECORD irec)
 
 	ASSERT(one && two);
 	ASSERT(eqstr(ntag(one), "FAMS") && eqstr(ntag(two), "FAMS"));
+
+/* Ask user to confirm */
+	if (!ask_yes_or_no(_(qScffswp)))
+		return FALSE;
+
 /* Swap FAMS nodes and update database */
 	str = nval(one);
 	nval(one) = nval(two);
