@@ -240,6 +240,7 @@ print_usage (void)
 	printf(_("\t-i = Check individuals\n"));
 	printf(_("\t-f = Check families\n"));
 	printf(_("\t-F = Alter any bad family lineage pointers (to _badptr)\n"));
+	printf(_("\t-h = Display help text (this text)\n"));
 	printf(_("\t-s = Check sours\n"));
 	printf(_("\t-e = Check events\n"));
 	printf(_("\t-x = Check others\n"));
@@ -373,8 +374,8 @@ static BOOLEAN
 cgn_callback (CNSTRING key, CNSTRING name, BOOLEAN newset, void *param)
 {
 	/* a name record which points at indi=key */
-	RECORD indi0 = qkey_to_irecord(key);
-	NODE indi = nztop(indi0);
+	RECORD indi0 = NULL;
+	NODE indi = NULL;
 	param=param; /* unused */
 
 	/* bail out immediately if not INDI */
@@ -384,6 +385,9 @@ cgn_callback (CNSTRING key, CNSTRING name, BOOLEAN newset, void *param)
 			, key, name);
 		return 1; /* continue traversal */
 	}
+	
+	indi0 = qkey_to_irecord(key);
+	indi = nztop(indi0);
 
 	if (newset) {
 		finish_and_delete_nameset();
@@ -1286,8 +1290,7 @@ check_typed_missing_data_records (char ntype)
  * main -- Main procedure of dbverify command
  *=========================================*/
 int
-main (int argc,
-      char **argv)
+main (int argc, char **argv)
 {
 	char *flags, *dbname;
 	char *ptr;
@@ -1297,6 +1300,7 @@ main (int argc,
 	BOOLEAN immut=FALSE; /* immutable access to database */
 	BOOLEAN allchecks=FALSE; /* if user requested all checks */
 	INT returnvalue=1;
+	STRING crashlog=NULL;
 
 	/* initialize all the low-level library code */
 	init_stdlib();
@@ -1342,6 +1346,7 @@ main (int argc,
 		case 'm': todo.check_missing_data_records=TRUE; break;
 		case 'M': todo.fix_missing_data_records=TRUE; break;
 		case 'D': todo.fix_deletes=TRUE; break;
+		case 'h':
 		default: print_usage(); goto done;
 		}
 	}
@@ -1359,6 +1364,12 @@ main (int argc,
 		printf("%s\n", msg);
 		goto done;
 	}
+
+	/* setup crashlog in case init_screen fails (eg, bad menu shortcuts) */
+	crashlog = getlloptstr("CrashLog_dbverify", NULL);
+	if (!crashlog) { crashlog = "Crashlog_dbverify.log"; }
+	crash_setcrashlog(crashlog);
+	
 	if (!(BTR = bt_openbtree(dbname, cflag, writ, immut))) {
 		char buffer[256];
 		describe_dberror(bterrno, buffer, ARRSIZE(buffer));
@@ -1377,7 +1388,7 @@ main (int argc,
 			goto done;
 	}
 
-	if (!init_lifelines_db()) {
+	if (!init_lifelines_postdb()) {
 		printf(_(qSbaddb));
 		goto done;
 	}
@@ -1414,6 +1425,9 @@ main (int argc,
 	report_results();
 
 	closebtree(BTR);
+
+	/* TODO: probably should call lldb_close, Perry 2005-10-07 */
+
 	BTR = 0;
 	returnvalue = 0;
 
@@ -1455,6 +1469,14 @@ report_results (void)
 void
 __fatal (STRING file, int line, CNSTRING details)
 {
+	/* avoid reentrancy */
+	static BOOLEAN failing=FALSE;
+	if (failing) return;
+	failing=TRUE;
+
+	/* send to error log if one is specified */
+	errlog_out(_("Fatal Error"), details, file, line);
+
 	printf(_("FATAL ERROR: "));
 	if (details && details[0]) {
 		printf(details);
@@ -1462,6 +1484,11 @@ __fatal (STRING file, int line, CNSTRING details)
 	printf("\n");
 	printf(_("In file <%s> at line %d"), file, line);
 	printf("\n");
+
+	/* offer crash dump before closing database */
+	ll_optional_abort(_("ASSERT failure"));
+
+	failing=FALSE;
 	exit(1);
 }
 /*===============================
